@@ -33,8 +33,10 @@ S_do_trans_simple(pTHX_ SV * const sv)
     STRLEN len;
     U8 *s = (U8*)SvPV(sv,len);
     U8 * const send = s+len;
-
     const short * const tbl = (short*)cPVOP->op_pv;
+
+    PERL_ARGS_ASSERT_DO_TRANS_SIMPLE;
+
     if (!tbl)
 	Perl_croak(aTHX_ "panic: do_trans_simple line %d",__LINE__);
 
@@ -59,8 +61,10 @@ S_do_trans_count(pTHX_ SV * const sv)
     const U8 *s = (const U8*)SvPV_const(sv, len);
     const U8 * const send = s + len;
     I32 matches = 0;
-
     const short * const tbl = (short*)cPVOP->op_pv;
+
+    PERL_ARGS_ASSERT_DO_TRANS_COUNT;
+
     if (!tbl)
 	Perl_croak(aTHX_ "panic: do_trans_count line %d",__LINE__);
     
@@ -80,8 +84,10 @@ S_do_trans_complex(pTHX_ SV * const sv)
     U8 *s = (U8*)SvPV(sv, len);
     U8 * const send = s+len;
     I32 matches = 0;
-
     const short * const tbl = (short*)cPVOP->op_pv;
+
+    PERL_ARGS_ASSERT_DO_TRANS_COMPLEX;
+
     if (!tbl)
 	Perl_croak(aTHX_ "panic: do_trans_complex line %d",__LINE__);
 
@@ -139,7 +145,6 @@ S_do_trans_simple_utf8(pTHX_ SV * const sv)
     I32 matches = 0;
     const I32 grows = PL_op->op_private & OPpTRANS_GROWS;
     STRLEN len;
-
     SV* const  rv =
 #ifdef USE_ITHREADS
 		    PAD_SVl(cPADOP->op_padix);
@@ -152,6 +157,8 @@ S_do_trans_simple_utf8(pTHX_ SV * const sv)
     const UV extra = none + 1;
     UV final = 0;
 
+    PERL_ARGS_ASSERT_DO_TRANS_SIMPLE_UTF8;
+
     s = SvPV(sv, len);
     send = s + len;
     start = s;
@@ -223,7 +230,6 @@ S_do_trans_count_utf8(pTHX_ SV * const sv)
     const char *send;
     I32 matches = 0;
     STRLEN len;
-
     SV* const  rv =
 #ifdef USE_ITHREADS
 		    PAD_SVl(cPADOP->op_padix);
@@ -235,6 +241,8 @@ S_do_trans_count_utf8(pTHX_ SV * const sv)
     const UV none = svp ? SvUV(*svp) : 0x7fffffff;
     const UV extra = none + 1;
 
+    PERL_ARGS_ASSERT_DO_TRANS_COUNT_UTF8;
+
     s = SvPV_const(sv, len);
     send = s + len;
 
@@ -273,6 +281,8 @@ S_do_trans_complex_utf8(pTHX_ SV * const sv)
     STRLEN len;
     char *dstart, *dend;
 
+    PERL_ARGS_ASSERT_DO_TRANS_COMPLEX_UTF8;
+
     char *s = SvPV(sv, len);
     send = s + len;
     start = s;
@@ -405,6 +415,8 @@ Perl_do_trans(pTHX_ SV *sv)
     STRLEN len;
     const I32 doutf = PL_op->op_private & OPpTRANS_UTF8;
 
+    PERL_ARGS_ASSERT_DO_TRANS;
+
     if (SvREADONLY(sv)) {
         if (SvIsCOW(sv))
             sv_force_normal_flags(sv, 0);
@@ -455,6 +467,8 @@ Perl_do_join(pTHX_ register SV *sv, SV *delim, register SV **mark, register SV *
     register STRLEN len;
     STRLEN delimlen;
 
+    PERL_ARGS_ASSERT_DO_JOIN;
+
     (void) SvPV_const(delim, delimlen); /* stringify and get the delimlen */
     /* SvCUR assumes it's SvPOK() and woe betide you if it's not. */
 
@@ -509,6 +523,8 @@ Perl_do_sprintf(pTHX_ SV *sv, I32 len, SV **sarg)
     const char * const pat = SvPV_const(*sarg, patlen);
     bool do_taint = FALSE;
 
+    PERL_ARGS_ASSERT_DO_SPRINTF;
+
     sv_vsetpvfn(sv, pat, patlen, NULL, sarg + 1, len - 1, &do_taint);
     SvSETMAGIC(sv);
     if (do_taint)
@@ -524,6 +540,8 @@ Perl_do_vecget(pTHX_ SV *sv, I32 offset, I32 size)
     const unsigned char *s = (const unsigned char *) SvPV_const(sv, srclen);
     UV retnum = 0;
 
+    PERL_ARGS_ASSERT_DO_VECGET;
+
     if (offset < 0)
 	return 0;
     if (size < 1 || (size & (size-1))) /* size < 1 or not a power of two */
@@ -671,6 +689,8 @@ Perl_do_vecset(pTHX_ SV *sv)
     STRLEN len;
     SV * const targ = LvTARG(sv);
 
+    PERL_ARGS_ASSERT_DO_VECSET;
+
     if (!targ)
 	return;
     s = (unsigned char*)SvPV_force(targ, targlen);
@@ -743,6 +763,8 @@ Perl_do_chop(pTHX_ register SV *astr, register SV *sv)
     STRLEN len;
     char *s;
 
+    PERL_ARGS_ASSERT_DO_CHOP;
+
     if (SvTYPE(sv) == SVt_PVAV) {
 	register I32 i;
 	AV* const av = (AV*)sv;
@@ -814,6 +836,8 @@ Perl_do_chomp(pTHX_ register SV *sv)
     char *temp_buffer = NULL;
     SV* svrecode = NULL;
 
+    PERL_ARGS_ASSERT_DO_CHOMP;
+
     if (RsSNARF(PL_rs))
 	return 0;
     if (RsRECORD(PL_rs))
@@ -919,6 +943,7 @@ Perl_do_vop(pTHX_ I32 optype, SV *sv, SV *left, SV *right)
     const char *rsave;
     STRLEN needlen = 0;
 
+    PERL_ARGS_ASSERT_DO_VOP;
 
     if (sv != left || (optype != OP_BIT_AND && !SvOK(sv) && !SvGMAGICAL(sv)))
 	sv_setpvn(sv, "", 0);	/* avoid undef warning on |= and ^= */
@@ -1034,7 +1059,7 @@ Perl_do_kv(pTHX)
     const I32 dovalues = dokv || (PL_op->op_type == OP_VALUES);
 
     if (!hv) {
-	if (PL_op->op_flags & OPf_MOD || LVRET) {	/* lvalue */
+	if (PL_op->op_flags & OPf_MOD) {	/* lvalue */
 	    SV * const sv = sv_newmortal();
 	    sv_upgrade(sv, SVt_PVLV);
 	    sv_magic(sv, NULL, PERL_MAGIC_nkeys, NULL, 0);
@@ -1053,7 +1078,7 @@ Perl_do_kv(pTHX)
     if (gimme == G_SCALAR) {
 	IV i;
 
-	if (PL_op->op_flags & OPf_MOD || LVRET) {	/* lvalue */
+	if (PL_op->op_flags & OPf_MOD) {	/* lvalue */
 	    SV * const sv = sv_newmortal();
 	    sv_upgrade(sv, SVt_PVLV);
 	    sv_magic(sv, NULL, PERL_MAGIC_nkeys, NULL, 0);
