@@ -6,16 +6,16 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.006 qw(createSelfTiedObject);
+use IO::Compress::Base::Common  v2.006 qw(createSelfTiedObject);
 
-use IO::Uncompress::Adapter::Inflate  2.006 ();
+use IO::Uncompress::Adapter::Inflate  v2.006 ();
 
 
-use IO::Uncompress::Base  2.006 ;
-use IO::Uncompress::Gunzip  2.006 ;
-use IO::Uncompress::Inflate  2.006 ;
-use IO::Uncompress::RawInflate  2.006 ;
-use IO::Uncompress::Unzip  2.006 ;
+use IO::Uncompress::Base  v2.006 ;
+use IO::Uncompress::Gunzip  v2.006 ;
+use IO::Uncompress::Inflate  v2.006 ;
+use IO::Uncompress::RawInflate  v2.006 ;
+use IO::Uncompress::Unzip  v2.006 ;
 
 require Exporter ;
 
@@ -48,7 +48,7 @@ sub anyinflate
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common  2.006 qw(:Parse);
+    use IO::Compress::Base::Common  v2.006 qw(:Parse);
     return ( 'RawInflate' => [1, 1, Parse_boolean,  0] ) ;
 }
 
