@@ -4,7 +4,7 @@ package threads::shared;
 use strict;
 use warnings;
 
-our $VERSION = '1.14';
+our $VERSION = '1.17';
 my $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -72,7 +72,7 @@ threads::shared - Perl extension for sharing data structures between threads
 
 =head1 VERSION
 
-This document describes threads::shared version 1.14
+This document describes threads::shared version 1.17
 
 =head1 SYNOPSIS
 
@@ -314,8 +314,11 @@ works on shared objects such that I<blessings> propagate across threads.
 
 =head1 NOTES
 
-threads::shared is designed to disable itself silently if threads are not
-available. If you want access to threads, you must C<use threads> before you
+L<threads::shared> is designed to disable itself silently if threads are not
+available.  This allows you to write modules and packages that can be used
+in both threaded and non-threaded applications.
+
+If you want access to threads, you must C<use threads> before you
 C<use threads::shared>.  L<threads> will emit a warning if you use it after
 L<threads::shared>.
 
@@ -359,7 +362,7 @@ error "locking can only be used on shared values" to occur when you attempt to
 C<< lock($hasref->{key}) >>.
 
 View existing bug reports at, and submit any new bugs, problems, patches, etc.
-to: L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=threads-shared>
+to: L<http://rt.cpan.org/Public/Dist/Display.html?Name=threads-shared>
 
 =head1 SEE ALSO
 
@@ -367,7 +370,7 @@ L<threads::shared> Discussion Forum on CPAN:
 L<http://www.cpanforum.com/dist/threads-shared>
 
 Annotated POD for L<threads::shared>:
-L<http://annocpan.org/~JDHEDDEN/threads-shared-1.14/shared.pm>
+L<http://annocpan.org/~JDHEDDEN/threads-shared-1.17/shared.pm>
 
 Source repository:
 L<http://code.google.com/p/threads-shared/>
