@@ -39,6 +39,8 @@ Perl stores its global variables.
 GV *
 Perl_gv_SVadd(pTHX_ GV *gv)
 {
+    PERL_ARGS_ASSERT_GV_SVADD;
+
     if (!gv || SvTYPE((SV*)gv) != SVt_PVGV)
 	Perl_croak(aTHX_ "Bad symbol for scalar");
     if (!GvSV(gv))
@@ -50,6 +52,8 @@ Perl_gv_SVadd(pTHX_ GV *gv)
 GV *
 Perl_gv_AVadd(pTHX_ register GV *gv)
 {
+    PERL_ARGS_ASSERT_GV_AVADD;
+
     if (!gv || SvTYPE((SV*)gv) != SVt_PVGV)
 	Perl_croak(aTHX_ "Bad symbol for array");
     if (!GvAV(gv))
@@ -60,6 +64,8 @@ Perl_gv_AVadd(pTHX_ register GV *gv)
 GV *
 Perl_gv_HVadd(pTHX_ register GV *gv)
 {
+    PERL_ARGS_ASSERT_GV_HVADD;
+
     if (!gv || SvTYPE((SV*)gv) != SVt_PVGV)
 	Perl_croak(aTHX_ "Bad symbol for hash");
     if (!GvHV(gv))
@@ -71,6 +77,9 @@ GV *
 Perl_gv_IOadd(pTHX_ register GV *gv)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_GV_IOADD;
+
     if (!gv || SvTYPE((SV*)gv) != SVt_PVGV) {
 
         /*
@@ -101,6 +110,7 @@ Perl_gv_IOadd(pTHX_ register GV *gv)
 GV *
 Perl_gv_fetchfile(pTHX_ const char *name)
 {
+    PERL_ARGS_ASSERT_GV_FETCHFILE;
     return gv_fetchfile_flags(name, strlen(name), 0);
 }
 
@@ -114,6 +124,7 @@ Perl_gv_fetchfile_flags(pTHX_ const char *const name, const STRLEN namelen,
     const STRLEN tmplen = namelen + 2;
     GV *gv;
 
+    PERL_ARGS_ASSERT_GV_FETCHFILE_FLAGS;
     PERL_UNUSED_ARG(flags);
 
     if (!PL_defstash)
@@ -157,6 +168,8 @@ NULL.
 SV *
 Perl_gv_const_sv(pTHX_ GV *gv)
 {
+    PERL_ARGS_ASSERT_GV_CONST_SV;
+
     if (SvTYPE(gv) == SVt_PVGV)
 	return cv_const_sv(GvCVu(gv));
     return SvROK(gv) ? SvRV(gv) : NULL;
@@ -176,6 +189,8 @@ Perl_newGP(pTHX_ GV *const gv)
     const char *file;
     STRLEN len;
 
+    PERL_ARGS_ASSERT_NEWGP;
+
     if (temp_sv) {
 	file = SvPVX(temp_sv);
 	len = SvCUR(temp_sv);
@@ -214,6 +229,7 @@ Perl_gv_init(pTHX_ GV *gv, HV *stash, const char *name, STRLEN len, int multi)
     SV *const has_constant = doproto && SvROK(gv) ? SvRV(gv) : NULL;
     const U32 exported_constant = has_constant ? SvPCS_IMPORTED(gv) : 0;
 
+    PERL_ARGS_ASSERT_GV_INIT;
     assert (!(proto && has_constant));
 
     if (has_constant) {
@@ -283,8 +299,10 @@ Perl_gv_init(pTHX_ GV *gv, HV *stash, const char *name, STRLEN len, int multi)
 }
 
 STATIC void
-S_gv_init_sv(pTHX_ GV *gv, I32 sv_type)
+S_gv_init_sv(pTHX_ GV *gv, const svtype sv_type)
 {
+    PERL_ARGS_ASSERT_GV_INIT_SV;
+
     switch (sv_type) {
     case SVt_PVIO:
 	(void)GvIOn(gv);
@@ -352,6 +370,8 @@ Perl_gv_fetchmeth(pTHX_ HV *stash, const char *name, STRLEN len, I32 level)
     STRLEN packlen;
     U32 topgen_cmp;
 
+    PERL_ARGS_ASSERT_GV_FETCHMETH;
+
     /* UNIVERSAL methods should be callable without a stash */
     if (!stash) {
 	create = 0;  /* probably appropriate */
@@ -492,6 +512,8 @@ S_gv_get_super_pkg(pTHX_ const char* name, I32 namelen)
     GV* gv;
     HV* stash;
 
+    PERL_ARGS_ASSERT_GV_GET_SUPER_PKG;
+
     stash = gv_stashpvn(name, namelen, 0);
     if(stash) return stash;
 
@@ -515,6 +537,17 @@ S_gv_get_super_pkg(pTHX_ const char* name, I32 namelen)
     return stash;
 }
 
+/* FIXME. If changing this function note the comment in pp_hot's
+   S_method_common:
+
+   This code tries to figure out just what went wrong with
+   gv_fetchmethod.  It therefore needs to duplicate a lot of
+   the internals of that function. ...
+
+   I'd guess that with one more flag bit that could all be moved inside
+   here.
+*/
+
 GV *
 Perl_gv_fetchmethod(pTHX_ HV *stash, const char *name)
 {
@@ -524,6 +557,8 @@ Perl_gv_fetchmethod(pTHX_ HV *stash, const char *name)
     GV* gv;
     HV* ostash = stash;
 
+    PERL_ARGS_ASSERT_GV_FETCHMETHOD;
+
     if (stash && SvTYPE(stash) < SVt_PVHV)
 	stash = NULL;
 
@@ -588,6 +623,8 @@ S_require_tie_mod(pTHX_ GV *gv, const char *varpv, SV* namesv, const char *methp
     dVAR;
     HV* stash = gv_stashsv(namesv, 0);
 
+    PERL_ARGS_ASSERT_REQUIRE_TIE_MOD;
+
     if (!stash || !(gv_fetchmethod(stash, methpv))) {
 	SV *module = newSVsv(namesv);
 	char varname = *varpv; /* varpv might be clobbered by load_module,
@@ -626,6 +663,7 @@ determine the length of C<name>, then calls C<gv_stashpvn()>.
 HV*
 Perl_gv_stashpv(pTHX_ const char *name, I32 create)
 {
+    PERL_ARGS_ASSERT_GV_STASHPV;
     return gv_stashpvn(name, strlen(name), create);
 }
 
@@ -651,6 +689,8 @@ Perl_gv_stashpvn(pTHX_ const char *name, U32 namelen, I32 flags)
     HV *stash;
     GV *tmpgv;
 
+    PERL_ARGS_ASSERT_GV_STASHPVN;
+
     if (namelen + 2 <= sizeof smallbuf)
 	tmpbuf = smallbuf;
     else
@@ -684,25 +724,30 @@ Perl_gv_stashsv(pTHX_ SV *sv, I32 flags)
 {
     STRLEN len;
     const char * const ptr = SvPV_const(sv,len);
+
+    PERL_ARGS_ASSERT_GV_STASHSV;
+
     return gv_stashpvn(ptr, len, flags);
 }
 
 
 GV *
-Perl_gv_fetchpv(pTHX_ const char *nambeg, I32 add, I32 sv_type) {
+Perl_gv_fetchpv(pTHX_ const char *nambeg, I32 add, const svtype sv_type) {
+    PERL_ARGS_ASSERT_GV_FETCHPV;
     return gv_fetchpvn_flags(nambeg, strlen(nambeg), add, sv_type);
 }
 
 GV *
-Perl_gv_fetchsv(pTHX_ SV *name, I32 flags, I32 sv_type) {
+Perl_gv_fetchsv(pTHX_ SV *name, I32 flags, const svtype sv_type) {
     STRLEN len;
     const char * const nambeg = SvPV_const(name, len);
+    PERL_ARGS_ASSERT_GV_FETCHSV;
     return gv_fetchpvn_flags(nambeg, len, flags, sv_type);
 }
 
 GV *
 Perl_gv_fetchpvn_flags(pTHX_ const char *nambeg, STRLEN full_len, I32 flags,
-		       I32 sv_type)
+		       const svtype sv_type)
 {
     dVAR;
     register const char *name = nambeg;
@@ -717,6 +762,8 @@ Perl_gv_fetchpvn_flags(pTHX_ const char *nambeg, STRLEN full_len, I32 flags,
     const char *const name_end = nambeg + full_len;
     const char *const name_em1 = name_end - 1;
 
+    PERL_ARGS_ASSERT_GV_FETCHPVN_FLAGS;
+
     if (flags & GV_NOTQUAL) {
 	/* Caller promised that there is no stash, so we can skip the check. */
 	len = full_len;
@@ -867,7 +914,7 @@ Perl_gv_fetchpvn_flags(pTHX_ const char *nambeg, STRLEN full_len, I32 flags,
     if (!stash) {
 	if (add) {
 	    SV * const err = Perl_mess(aTHX_
-		 "Global symbol \"%s%s\" requires explicit package name",
+		 "Global symbol \"%s%s\" requires explicit package name\n",
 		 (sv_type == SVt_PV ? "$"
 		  : sv_type == SVt_PVAV ? "@"
 		  : sv_type == SVt_PVHV ? "%"
@@ -992,6 +1039,10 @@ Perl_gv_fetchpvn_flags(pTHX_ const char *nambeg, STRLEN full_len, I32 flags,
 		if (strEQ(name2, "HILD_ERROR_NATIVE"))
 		    goto magicalize;
 		break;
+	    case '\004':        /* $^DIE_HOOK */
+		if (strEQ(name2, "IE_HOOK"))
+		    goto magicalize;
+		break;
 	    case '\005':	/* $^ENCODING */
 		if (strEQ(name2, "NCODING"))
 		    goto magicalize;
@@ -1018,7 +1069,9 @@ Perl_gv_fetchpvn_flags(pTHX_ const char *nambeg, STRLEN full_len, I32 flags,
 		if (strEQ(name2, "TF8CACHE"))
 		    goto magicalize;
 		break;
-	    case '\027':	/* $^WARNING_BITS */
+	    case '\027':	/* $^WARNING_BITS, $^WARN_HOOK */
+		if (strEQ(name2, "ARN_HOOK"))
+		    goto magicalize;
 		if (strEQ(name2, "ARNING_BITS"))
 		    goto magicalize;
 		break;
@@ -1160,7 +1213,7 @@ Perl_gv_fetchpvn_flags(pTHX_ const char *nambeg, STRLEN full_len, I32 flags,
 	    break;
 	case ']':
 	{
-	    Perl_croak(aTHX "$] is obsolete. Use $^V or $kurila::VERSION");
+	    Perl_croak(aTHX_ "$] is obsolete. Use $^V or $kurila::VERSION");
 	}
 	break;
 	case '\026':	/* $^V */
@@ -1180,6 +1233,9 @@ Perl_gv_fullname4(pTHX_ SV *sv, const GV *gv, const char *prefix, bool keepmain)
     const char *name;
     STRLEN namelen;
     const HV * const hv = GvSTASH(gv);
+
+    PERL_ARGS_ASSERT_GV_FULLNAME4;
+
     if (!hv) {
 	SvOK_off(sv);
 	return;
@@ -1205,6 +1261,9 @@ void
 Perl_gv_efullname4(pTHX_ SV *sv, const GV *gv, const char *prefix, bool keepmain)
 {
     const GV * const egv = GvEGV(gv);
+
+    PERL_ARGS_ASSERT_GV_EFULLNAME4;
+
     gv_fullname4(sv, egv ? egv : gv, prefix, keepmain);
 }
 
@@ -1235,6 +1294,8 @@ Perl_gv_check(pTHX_ const HV *stash)
     dVAR;
     register I32 i;
 
+    PERL_ARGS_ASSERT_GV_CHECK;
+
     if (!HvARRAY(stash))
 	return;
     for (i = 0; i <= (I32) HvMAX(stash); i++) {
@@ -1273,6 +1334,9 @@ GV *
 Perl_newGVgen(pTHX_ const char *pack)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_NEWGVGEN;
+
     return gv_fetchpv(Perl_form(aTHX_ "%s::_GEN_%ld", pack, (long)PL_gensym++),
 		      GV_ADD, SVt_PVGV);
 }
@@ -1347,6 +1411,8 @@ Perl_magic_freeovrld(pTHX_ SV *sv, MAGIC *mg)
     AMT * const amtp = (AMT*)mg->mg_ptr;
     PERL_UNUSED_ARG(sv);
 
+    PERL_ARGS_ASSERT_MAGIC_FREEOVRLD;
+
     if (amtp && AMT_AMAGIC(amtp)) {
 	int i;
 	for (i = 1; i < NofAMmeth; i++) {
@@ -1371,6 +1437,8 @@ Perl_Gv_AMupdate(pTHX_ HV *stash)
   const struct mro_meta* stash_meta = HvMROMETA(stash);
   U32 newgen;
 
+  PERL_ARGS_ASSERT_GV_AMUPDATE;
+
   newgen = PL_sub_generation + stash_meta->pkg_gen + stash_meta->cache_gen;
   if (mg) {
       const AMT * const amtp = (AMT*)mg->mg_ptr;
@@ -1513,6 +1581,9 @@ Perl_amagic_call(pTHX_ SV *left, SV *right, int method, int flags)
   int fl=0;
 #endif
   HV* stash=NULL;
+
+  PERL_ARGS_ASSERT_AMAGIC_CALL;
+
   if (!(AMGf_noleft & flags) && SvAMAGIC(left)
       && (stash = SvSTASH(SvRV(left)))
       && (mg = mg_find((SV*)stash, PERL_MAGIC_overload_table))
@@ -1879,6 +1950,9 @@ Perl_is_gv_magical_sv(pTHX_ SV *name, U32 flags)
 {
     STRLEN len;
     const char * const temp = SvPV_const(name, len);
+
+    PERL_ARGS_ASSERT_IS_GV_MAGICAL_SV;
+
     return is_gv_magical(temp, len, flags);
 }
 
@@ -1905,6 +1979,8 @@ Perl_is_gv_magical(pTHX_ const char *name, STRLEN len, U32 flags)
     PERL_UNUSED_CONTEXT;
     PERL_UNUSED_ARG(flags);
 
+    PERL_ARGS_ASSERT_IS_GV_MAGICAL;
+
     if (len > 1) {
 	const char * const name1 = name + 1;
 	switch (*name) {
@@ -1923,6 +1999,10 @@ Perl_is_gv_magical(pTHX_ const char *name, STRLEN len, U32 flags)
 	    /* Using ${^...} variables is likely to be sufficiently rare that
 	       it seems sensible to avoid the space hit of also checking the
 	       length.  */
+	case '\004':    /* ${^DIE_HOOK} */
+	    if (strEQ(name1, "IE_HOOK"))
+		goto yes;
+	    break;
 	case '\017':   /* ${^OPEN} */
 	    if (strEQ(name1, "PEN"))
 		goto yes;
@@ -1940,6 +2020,8 @@ Perl_is_gv_magical(pTHX_ const char *name, STRLEN len, U32 flags)
 	case '\027':   /* ${^WARNING_BITS} */
 	    if (strEQ(name1, "ARNING_BITS"))
 		goto yes;
+	    if (strEQ(name1, "ARN_HOOK"))
+		goto yes;
 	    break;
 	case '1':
 	case '2':
@@ -2027,7 +2109,7 @@ Perl_gv_name_set(pTHX_ GV *gv, const char *name, U32 len, U32 flags)
     dVAR;
     U32 hash;
 
-    assert(name);
+    PERL_ARGS_ASSERT_GV_NAME_SET;
     PERL_UNUSED_ARG(flags);
 
     if (len > I32_MAX)
