@@ -40,11 +40,10 @@ with a volume name, a relative pathname should always begin with a
 
 =cut
 
-use Carp;
 use Symbol;
 
 sub new {
-    @_ +>= 1 && @_ +<= 2 or croak 'usage: new DirHandle [DIRNAME]';
+    @_ +>= 1 && @_ +<= 2 or die 'usage: new DirHandle [DIRNAME]';
     my $class = shift;
     my $dh = gensym;
     if (@_) {
@@ -63,25 +62,25 @@ sub DESTROY {
 }
 
 sub open {
-    @_ == 2 or croak 'usage: $dh->open(DIRNAME)';
+    @_ == 2 or die 'usage: $dh->open(DIRNAME)';
     my ($dh, $dirname) = @_;
     opendir($dh, $dirname);
 }
 
 sub close {
-    @_ == 1 or croak 'usage: $dh->close()';
+    @_ == 1 or die 'usage: $dh->close()';
     my ($dh) = @_;
     closedir($dh);
 }
 
 sub read {
-    @_ == 1 or croak 'usage: $dh->read()';
+    @_ == 1 or die 'usage: $dh->read()';
     my ($dh) = @_;
     readdir($dh);
 }
 
 sub rewind {
-    @_ == 1 or croak 'usage: $dh->rewind()';
+    @_ == 1 or die 'usage: $dh->rewind()';
     my ($dh) = @_;
     rewinddir($dh);
 }
