@@ -2,13 +2,12 @@ package ExtUtils::MM;
 
 use strict;
 use ExtUtils::MakeMaker::Config;
-use vars qw(@ISA $VERSION);
-$VERSION = '0.07';
+
+our $VERSION = '6.43_01';
 
 require ExtUtils::Liblist;
 require ExtUtils::MakeMaker;
-
-@ISA = qw(ExtUtils::Liblist ExtUtils::MakeMaker);
+our @ISA = qw(ExtUtils::Liblist ExtUtils::MakeMaker);
 
 =head1 NAME
 
@@ -38,23 +37,23 @@ away.
 {
     # Convenient alias.
     package MM;
-    use vars qw(@ISA);
-    @ISA = qw(ExtUtils::MM);
+    our @ISA = qw(ExtUtils::MM);
     sub DESTROY {}
 }
 
+sub _is_win95 {
+    # miniperl might not have the Win32 functions available and we need
+    # to run in miniperl.
+    return defined &Win32::IsWin95 ? Win32::IsWin95() 
+                                   : ! defined $ENV{SYSTEMROOT}; 
+}
+
 my %Is = ();
 $Is{VMS}    = $^O eq 'VMS';
 $Is{OS2}    = $^O eq 'os2';
 $Is{MacOS}  = $^O eq 'MacOS';
 if( $^O eq 'MSWin32' ) {
-    if (defined &DynaLoader::boot_DynaLoader) {
-	Win32::IsWin95() ? $Is{Win95} = 1 : $Is{Win32} = 1;
-    }
-    else {
-	# Can't use Win32::* with miniperl
-	!(defined $ENV{SYSTEMROOT}) ? $Is{Win95} = 1 : $Is{Win32} = 1;
-    }
+    _is_win95() ? $Is{Win95} = 1 : $Is{Win32} = 1;
 }
 $Is{UWIN}   = $^O =~ m/^uwin(-nt)?$/;
 $Is{Cygwin} = $^O eq 'cygwin';
@@ -68,6 +67,7 @@ if( $Is{NW5} ) {
 $Is{VOS}    = $^O eq 'vos';
 $Is{QNX}    = $^O eq 'qnx';
 $Is{AIX}    = $^O eq 'aix';
+$Is{Darwin} = $^O eq 'darwin';
 
 $Is{Unix}   = !grep { $_ } values %Is;
 
@@ -77,7 +77,7 @@ my($OS) = keys %Is;
 
 
 my $class = "ExtUtils::MM_$OS";
-eval "require $class" unless $INC{"ExtUtils/MM_$OS.pm"};
+eval "require $class" unless $INC{"ExtUtils/MM_$OS.pm"}; ## no critic
 die $@ if $@;
 unshift @ISA, $class;
 
