@@ -25,9 +25,8 @@ use File::Spec;
 require ExtUtils::MM_Any;
 require ExtUtils::MM_Unix;
 
-use vars qw(@ISA $VERSION);
-@ISA = qw( ExtUtils::MM_Unix );
-$VERSION = '1.07';
+our @ISA = qw( ExtUtils::MM_Unix );
+our $VERSION = '6.43_01';
 
 
 =item os_flavor
