@@ -1,16 +1,15 @@
 package ExtUtils::MM_OS2;
 
 use strict;
-use vars qw($VERSION @ISA);
 
 use ExtUtils::MakeMaker qw(neatvalue);
 use File::Spec;
 
-$VERSION = '1.07';
+our $VERSION = '6.43_01';
 
 require ExtUtils::MM_Any;
 require ExtUtils::MM_Unix;
-@ISA = qw(ExtUtils::MM_Unix);
+our @ISA = qw(ExtUtils::MM_Unix);
 
 =pod
 
@@ -75,13 +74,12 @@ $self->{BASEEXT}.def: Makefile.PL
     if ($self->{IMPORTS} && %{$self->{IMPORTS}}) {
 	# Make import files (needed for static build)
 	-d 'tmp_imp' or mkdir 'tmp_imp', 0777 or die "Can't mkdir tmp_imp";
-	open IMP, ">", 'tmpimp.imp' or die "Can't open tmpimp.imp";
-	my ($name, $exp);
-	while (($name, $exp)= each %{$self->{IMPORTS}}) {
+	open my $imp, '>', 'tmpimp.imp' or die "Can't open tmpimp.imp";
+	while (my($name, $exp) = each %{$self->{IMPORTS}}) {
 	    my ($lib, $id) = ($exp =~ m/(.*)\.(.*)/) or die "Malformed IMPORT `$exp'";
-	    print IMP "$name $lib $id ?\n";
+	    print $imp "$name $lib $id ?\n";
 	}
-	close IMP or die "Can't close tmpimp.imp";
+	close $imp or die "Can't close tmpimp.imp";
 	# print "emximp -o tmpimp$Config::Config{lib_ext} tmpimp.imp\n";
 	system "emximp -o tmpimp$Config::Config{lib_ext} tmpimp.imp" 
 	    and die "Cannot make import library: $!, \$?=$?";
