@@ -1,7 +1,6 @@
 package ExtUtils::Packlist;
 
 use strict;
-use Carp qw();
 use Config;
 use vars qw($VERSION $Relocations);
 $VERSION = '1.43';
@@ -115,9 +114,9 @@ $self = tied(%$self) || $self;
 
 if (defined($packfile)) { $self->{packfile} = $packfile; }
 else { $packfile = $self->{packfile}; }
-Carp::croak("No packlist filename specified") if (! defined($packfile));
+die("No packlist filename specified") if (! defined($packfile));
 my $fh = mkfh();
-open($fh, "<", "$packfile") || Carp::croak("Can't open file $packfile: $!");
+open($fh, "<", "$packfile") || die("Can't open file $packfile: $!");
 $self->{data} = {};
 my ($line);
 while (defined($line = ~< $fh))
@@ -150,9 +149,9 @@ my ($self, $packfile) = @_;
 $self = tied(%$self) || $self;
 if (defined($packfile)) { $self->{packfile} = $packfile; }
 else { $packfile = $self->{packfile}; }
-Carp::croak("No packlist filename specified") if (! defined($packfile));
+die("No packlist filename specified") if (! defined($packfile));
 my $fh = mkfh();
-open($fh, ">", "$packfile") || Carp::croak("Can't open file $packfile: $!");
+open($fh, ">", "$packfile") || die("Can't open file $packfile: $!");
 foreach my $key (sort(keys(%{$self->{data}})))
    {
        my $data = $self->{data}->{$key};
