@@ -1,9 +1,9 @@
 package ExtUtils::testlib;
 
 use strict;
+use warnings;
 
-use vars qw($VERSION);
-$VERSION = 1.17;
+our $VERSION = 6.43_01;
 
 use Cwd;
 use File::Spec;
@@ -17,7 +17,7 @@ my $cwd;
 BEGIN {
     ($cwd) = getcwd() =~ m/(.*)/;
 }
-use lib map File::Spec->rel2abs($_, $cwd), qw(blib/arch blib/lib);
+use lib map { File::Spec->rel2abs($_, $cwd) } qw(blib/arch blib/lib);
 1;
 __END__
 
