@@ -15,7 +15,7 @@ use strict;
 @ISA     = qw(Net::LocalCfg Exporter);
 $VERSION = "1.11";
 
-eval { local $SIG{__DIE__}; require Net::LocalCfg };
+eval { require Net::LocalCfg };
 
 %NetConfig = (
   nntp_hosts      => [],
@@ -61,18 +61,18 @@ my $file = __FILE__;
 my $ref;
 $file =~ s/Config.pm/libnet.cfg/;
 if (-f $file) {
-  $ref = eval { local $SIG{__DIE__}; do $file };
+  $ref = eval { do $file };
   if (ref($ref) eq 'HASH') {
     %NetConfig = (%NetConfig, %{$ref});
     $LIBNET_CFG = $file;
   }
 }
 if ($< == $> and !$CONFIGURE) {
-  my $home = eval { local $SIG{__DIE__}; (getpwuid($>))[7] } || $ENV{HOME};
+  my $home = eval { (getpwuid($>))[7] } || $ENV{HOME};
   $home ||= $ENV{HOMEDRIVE} . ($ENV{HOMEPATH} || '') if defined $ENV{HOMEDRIVE};
   if (defined $home) {
     $file      = $home . "/.libnetrc";
-    $ref       = eval { local $SIG{__DIE__}; do $file } if -f $file;
+    $ref       = eval { do $file } if -f $file;
     %NetConfig = (%NetConfig, %{$ref})
       if ref($ref) eq 'HASH';
   }
