@@ -21,7 +21,7 @@ $WRAP = 1 unless defined $WRAP;
 sub _openclose {
  return map {;
    m/^([-A-Za-z]+)=(\w[^\=]*)$/s or die "what's <$_>?";
-   ( $1,  "{\\$2\n",   "/$1",  "}" );
+   ( $1,  "\{\\$2\n",   "/$1",  "\}" );
  } @_;
 }
 
@@ -62,28 +62,28 @@ my @_to_accept;
  'Data'  => "\n",
  '/Data' => "\n",
 
- 'Verbatim'  => "\n{\\pard\\li#rtfindent##rtfkeep#\\plain\\s20\\sa180\\f1\\fs18\\lang1024\\noproof\n",
- '/Verbatim' => "\n\\par}\n",
- 'VerbatimFormatted'  => "\n{\\pard\\li#rtfindent##rtfkeep#\\plain\\s20\\sa180\\f1\\fs18\\lang1024\\noproof\n",
- '/VerbatimFormatted' => "\n\\par}\n",
- 'Para'    => "\n{\\pard\\li#rtfindent#\\sa180\n",
- '/Para'   => "\n\\par}\n",
- 'head1'   => "\n{\\pard\\li#rtfindent#\\s31\\keepn\\sb90\\sa180\\f2\\fs#head1_halfpoint_size#\\ul{\n",
- '/head1'  => "\n}\\par}\n",
- 'head2'   => "\n{\\pard\\li#rtfindent#\\s32\\keepn\\sb90\\sa180\\f2\\fs#head2_halfpoint_size#\\ul{\n",
- '/head2'  => "\n}\\par}\n",
- 'head3'   => "\n{\\pard\\li#rtfindent#\\s33\\keepn\\sb90\\sa180\\f2\\fs#head3_halfpoint_size#\\ul{\n",
- '/head3'  => "\n}\\par}\n",
- 'head4'   => "\n{\\pard\\li#rtfindent#\\s34\\keepn\\sb90\\sa180\\f2\\fs#head4_halfpoint_size#\\ul{\n",
- '/head4'  => "\n}\\par}\n",
+ 'Verbatim'  => "\n\{\\pard\\li#rtfindent##rtfkeep#\\plain\\s20\\sa180\\f1\\fs18\\lang1024\\noproof\n",
+ '/Verbatim' => "\n\\par\}\n",
+ 'VerbatimFormatted'  => "\n\{\\pard\\li#rtfindent##rtfkeep#\\plain\\s20\\sa180\\f1\\fs18\\lang1024\\noproof\n",
+ '/VerbatimFormatted' => "\n\\par\}\n",
+ 'Para'    => "\n\{\\pard\\li#rtfindent#\\sa180\n",
+ '/Para'   => "\n\\par\}\n",
+ 'head1'   => "\n\{\\pard\\li#rtfindent#\\s31\\keepn\\sb90\\sa180\\f2\\fs#head1_halfpoint_size#\\ul\{\n",
+ '/head1'  => "\n\}\\par\}\n",
+ 'head2'   => "\n\{\\pard\\li#rtfindent#\\s32\\keepn\\sb90\\sa180\\f2\\fs#head2_halfpoint_size#\\ul\{\n",
+ '/head2'  => "\n\}\\par\}\n",
+ 'head3'   => "\n\{\\pard\\li#rtfindent#\\s33\\keepn\\sb90\\sa180\\f2\\fs#head3_halfpoint_size#\\ul\{\n",
+ '/head3'  => "\n\}\\par\}\n",
+ 'head4'   => "\n\{\\pard\\li#rtfindent#\\s34\\keepn\\sb90\\sa180\\f2\\fs#head4_halfpoint_size#\\ul\{\n",
+ '/head4'  => "\n\}\\par\}\n",
    # wordpad borks on \tc\tcl1, or I'd put that in =head1 and =head2
 
- 'item-bullet'  => "\n{\\pard\\li#rtfindent##rtfitemkeepn#\\sb60\\sa150\\fi-120\n",
- '/item-bullet' => "\n\\par}\n",
- 'item-number'  => "\n{\\pard\\li#rtfindent##rtfitemkeepn#\\sb60\\sa150\\fi-120\n",
- '/item-number' => "\n\\par}\n",
- 'item-text'    => "\n{\\pard\\li#rtfindent##rtfitemkeepn#\\sb60\\sa150\\fi-120\n",
- '/item-text'   => "\n\\par}\n",
+ 'item-bullet'  => "\n\{\\pard\\li#rtfindent##rtfitemkeepn#\\sb60\\sa150\\fi-120\n",
+ '/item-bullet' => "\n\\par\}\n",
+ 'item-number'  => "\n\{\\pard\\li#rtfindent##rtfitemkeepn#\\sb60\\sa150\\fi-120\n",
+ '/item-number' => "\n\\par\}\n",
+ 'item-text'    => "\n\{\\pard\\li#rtfindent##rtfitemkeepn#\\sb60\\sa150\\fi-120\n",
+ '/item-text'   => "\n\\par\}\n",
 
  # we don't need any styles for over-* and /over-*
 );
@@ -100,7 +100,7 @@ sub new {
 
   $new->accept_codes(@_to_accept);
   $new->accept_codes('VerbatimFormatted');
-  DEBUG > 2 and print "To accept: ", join(' ',@_to_accept), "\n";
+  DEBUG +> 2 and print "To accept: ", join(' ',@_to_accept), "\n";
   $new->doc_lang(
     (  $ENV{'RTFDEFLANG'} || '') =~ m/^(\d{1,10})$/s ? $1
     : ($ENV{'RTFDEFLANG'} || '') =~ m/^0?x([a-fA-F0-9]{1,10})$/s ? hex($1)
@@ -160,13 +160,13 @@ sub do_middle {      # the main work
   
     if( ($type = $token->type) eq 'text' ) {
       if( $self->{'rtfverbatim'} ) {
-        DEBUG > 1 and print "  $type " , $token->text, " in verbatim!\n";
+        DEBUG +> 1 and print "  $type " , $token->text, " in verbatim!\n";
         rtf_esc_codely($scratch = $token->text);
         print $fh $scratch;
         next;
       }
 
-      DEBUG > 1 and print "  $type " , $token->text, "\n";
+      DEBUG +> 1 and print "  $type " , $token->text, "\n";
       
       $scratch = $token->text;
       $scratch =~ tr/\t\cb\cc/ /d;
@@ -184,7 +184,7 @@ sub do_middle {      # the main work
           |
           # or starting alpha, but containing anything strange:
           (?:
-           [a-zA-Z'\x80-\xFF]+[\$\@\:_<>\(\\\*]\S+
+           [a-zA-Z'\x[80]-\x[FF]]+[\$\@\:_<>\(\\\*]\S+
           )
          )
         /\cb$1\cc/xsg
@@ -194,9 +194,9 @@ sub do_middle {      # the main work
       $scratch =~
          s/(
             [^\cm\cj\n]{65}        # Snare 65 characters from a line
-            [^\cm\cj\n\x20]{0,50}  #  and finish any current word
+            [^\cm\cj\n\x[20]]{0,50}  #  and finish any current word
            )
-           (\x20{1,10})(?![\cm\cj\n]) # capture some spaces not at line-end
+           (\x[20]{1,10})(?![\cm\cj\n]) # capture some spaces not at line-end
           /$1$2\n/gx     # and put a NL before those spaces
         if $WRAP;
         # This may wrap at well past the 65th column, but not past the 120th.
@@ -204,7 +204,7 @@ sub do_middle {      # the main work
       print $fh $scratch;
 
     } elsif( $type eq 'start' ) {
-      DEBUG > 1 and print "  +$type ",$token->tagname,
+      DEBUG +> 1 and print "  +$type ",$token->tagname,
         " (", map("<$_> ", %{$token->attr_hash}), ")\n";
 
       if( ($tagname = $token->tagname) eq 'Verbatim'
@@ -217,12 +217,12 @@ sub do_middle {      # the main work
         if($next->type eq 'text') {
           my $t = $next->text_r;
           while( $$t =~ m/$/mg ) {
-            last if  ++$line_count  > 15; # no point in counting further
+            last if  ++$line_count  +> 15; # no point in counting further
           }
-          DEBUG > 3 and print "    verbatim line count: $line_count\n";
+          DEBUG +> 3 and print "    verbatim line count: $line_count\n";
         }
         $self->unget_token($next);
-        $self->{'rtfkeep'} = ($line_count > 15) ? '' : '\keepn' ;     
+        $self->{'rtfkeep'} = ($line_count +> 15) ? '' : '\keepn' ;     
 
       } elsif( $tagname =~ m/^item-/s ) {
         my @to_unget;
@@ -240,11 +240,11 @@ sub do_middle {      # the main work
            # of removes, and operates on the beginning instead of the end!
           
           if($to_unget[-1]->type eq 'text') {
-            if( ($text_count_here += length ${$to_unget[-1]->text_r}) > 150 ){
-              DEBUG > 1 and print "    item-* is too long to be keepn'd.\n";
+            if( ($text_count_here += length ${$to_unget[-1]->text_r}) +> 150 ){
+              DEBUG +> 1 and print "    item-* is too long to be keepn'd.\n";
               last;
             }
-          } elsif (@to_unget > 1 and
+          } elsif (@to_unget +> 1 and
             $to_unget[-2]->type eq 'end' and
             $to_unget[-2]->tagname =~ m/^item-/s
           ) {
@@ -253,15 +253,15 @@ sub do_middle {      # the main work
               $to_unget[-1]->type eq 'start' and
               $to_unget[-1]->tagname eq 'Para';
 
-            DEBUG > 1 and printf "    item-* before %s(%s) %s keepn'd.\n",
+            DEBUG +> 1 and printf "    item-* before %s(%s) %s keepn'd.\n",
               $to_unget[-1]->type,
               $to_unget[-1]->can('tagname') ? $to_unget[-1]->tagname : '',
               $self->{'rtfitemkeepn'} ? "gets" : "doesn't get";
             last;
-          } elsif (@to_unget > 40) {
-            DEBUG > 1 and print "    item-* now has too many tokens (",
+          } elsif (@to_unget +> 40) {
+            DEBUG +> 1 and print "    item-* now has too many tokens (",
               scalar(@to_unget),
-              (DEBUG > 4) ? (q<: >, map($_->dump, @to_unget)) : (),
+              (DEBUG +> 4) ? (q<: >, map($_->dump, @to_unget)) : (),
               ") to be keepn'd.\n";
             last; # give up
           }
@@ -304,7 +304,7 @@ sub do_middle {      # the main work
       }
 
     } elsif( $type eq 'end' ) {
-      DEBUG > 1 and print "  -$type ",$token->tagname,"\n";
+      DEBUG +> 1 and print "  -$type ",$token->tagname,"\n";
       if( ($tagname = $token->tagname) =~ m/^over-/s ) {
         DEBUG and print "Indenting back $indent_stack[-1] twips.\n";
         $self->{'rtfindent'} -= pop @indent_stack;
@@ -433,7 +433,7 @@ END
   # None of the following things should need escaping, I dare say!
     $tag, 
     $ISA[0], $ISA[0]->VERSION(),
-    $], scalar(gmtime),
+    $^V, scalar(gmtime),
   ;
 }
 
@@ -483,20 +483,20 @@ sub rtf_esc {
   if(!defined wantarray) { # void context: alter in-place!
     for(@_) {
       s/([F\x00-\x1F\-\\\{\}\x7F-\xFF])/$Escape{$1}/g;  # ESCAPER
-      s/([^\x00-\xFF])/'\\uc1\\u'.((ord($1)<32768)?ord($1):(ord($1)-65536)).'?'/eg;
+      s/([^\x00-\xFF])/{'\\uc1\\u'.((ord($1)+<32768)?ord($1):(ord($1)-65536)).'?'}/g;
     }
     return;
   } elsif(wantarray) {  # return an array
     return map {; ($x = $_) =~
       s/([F\x00-\x1F\-\\\{\}\x7F-\xFF])/$Escape{$1}/g;  # ESCAPER
-      $x =~ s/([^\x00-\xFF])/'\\uc1\\u'.((ord($1)<32768)?ord($1):(ord($1)-65536)).'?'/eg;
+      $x =~ s/([^\x00-\xFF])/{'\\uc1\\u'.((ord($1)+<32768)?ord($1):(ord($1)-65536)).'?'}/g;
       $x;
     } @_;
   } else { # return a single scalar
     ($x = ((@_ == 1) ? $_[0] : join '', @_)
     ) =~ s/([F\x00-\x1F\-\\\{\}\x7F-\xFF])/$Escape{$1}/g;  # ESCAPER
              # Escape \, {, }, -, control chars, and 7f-ff.
-    $x =~ s/([^\x00-\xFF])/'\\uc1\\u'.((ord($1)<32768)?ord($1):(ord($1)-65536)).'?'/eg;
+    $x =~ s/([^\x00-\xFF])/{'\\uc1\\u'.((ord($1)+<32768)?ord($1):(ord($1)-65536)).'?'}/g;
     return $x;
   }
 }
@@ -512,20 +512,20 @@ sub rtf_esc_codely {
   if(!defined wantarray) { # void context: alter in-place!
     for(@_) {
       s/([F\x00-\x1F\\\{\}\x7F-\xFF])/$Escape{$1}/g;  # ESCAPER
-      s/([^\x00-\xFF])/'\\uc1\\u'.((ord($1)<32768)?ord($1):(ord($1)-65536)).'?'/eg;
+      s/([^\x00-\xFF])/{'\\uc1\\u'.((ord($1)+<32768)?ord($1):(ord($1)-65536)).'?'}/g;
     }
     return;
   } elsif(wantarray) {  # return an array
     return map {; ($x = $_) =~
       s/([F\x00-\x1F\\\{\}\x7F-\xFF])/$Escape{$1}/g;  # ESCAPER
-      $x =~ s/([^\x00-\xFF])/'\\uc1\\u'.((ord($1)<32768)?ord($1):(ord($1)-65536)).'?'/eg;
+      $x =~ s/([^\x00-\xFF])/{'\\uc1\\u'.((ord($1)+<32768)?ord($1):(ord($1)-65536)).'?'}/g;
       $x;
     } @_;
   } else { # return a single scalar
     ($x = ((@_ == 1) ? $_[0] : join '', @_)
     ) =~ s/([F\x00-\x1F\\\{\}\x7F-\xFF])/$Escape{$1}/g;  # ESCAPER
              # Escape \, {, }, -, control chars, and 7f-ff.
-    $x =~ s/([^\x00-\xFF])/'\\uc1\\u'.((ord($1)<32768)?ord($1):(ord($1)-65536)).'?'/eg;
+    $x =~ s/([^\x00-\xFF])/{'\\uc1\\u'.((ord($1)+<32768)?ord($1):(ord($1)-65536)).'?'}/g;
     return $x;
   }
 }
@@ -554,8 +554,8 @@ sub rtf_esc_codely {
   # CRAZY HACKS:
   "\n" => "\\line\n",
   "\r" => "\n",
-  "\cb" => "{\n\\cs21\\lang1024\\noproof ",  # \\cf1
-  "\cc" => "}",
+  "\cb" => "\{\n\\cs21\\lang1024\\noproof ",  # \\cf1
+  "\cc" => "\}",
 );
 1;
 
