@@ -27,12 +27,10 @@ sub _handle_element_start {
 }
 
 sub _handle_text {
-  if( chr(65) eq 'A' ) {     # in ASCIIworld
-    $_[1] =~ tr/\xAD//d;
-    $_[1] =~ tr/\xA0/ /;
-  }
-  print {$_[0]{'output_fh'}} $_[1];
-  return;
+    $_[1] =~ tr/\x{AD}//d;
+    $_[1] =~ tr/\x{A0}/ /;
+    print {$_[0]{'output_fh'}} $_[1];
+    return;
 }
 
 sub _handle_element_end {
