@@ -12,10 +12,9 @@ $VERSION = '2.02';
 %Supported = (
   'ascii'       => 1,
   'ascii-ctrl'  => 1,
-  'iso-8859-1'  => 1,
+  'utf8'  => 1,
   'null'        => 1,
-  'latin1'      => 1,
-  'latin-1'     => 1,
+  'latin1' => 1,
   %Supported,
 );
 
@@ -38,9 +37,13 @@ sub make_transcoder {
   my($e) = $_[1];
   die "WHAT ENCODING!?!?" unless $e;
   my $x;
+  if ($e eq "latin1") {
+      return sub { return map { join '', map { utf8::chr($_) } unpack "C*", $_; } @_ };
+  }
+
   return sub {;
     #foreach $x (@_) {
-    #  if(Pod::Simple::ASCII and !Pod::Simple::UNICODE and $] > 5.005) {
+    #  if(Pod::Simple::ASCII and !Pod::Simple::UNICODE) {
     #    # We're in horrible gimp territory, so we need to knock out
     #    # all the highbit things
     #    $x =
