@@ -2,8 +2,10 @@ package bytes;
 
 our $VERSION = '1.03';
 
-$bytes::hint_bits = 0x00000008;
-$bytes::codepoints_hint_bits = 0x01000000;
+BEGIN {
+    $bytes::hint_bits = 0x00000008;
+    $bytes::codepoints_hint_bits = 0x01000000;
+}
 
 sub import {
     $^H ^|^= $bytes::hint_bits;
@@ -14,21 +16,40 @@ sub unimport {
     $^H ^&^= ^~^$bytes::hint_bits;
 }
 
-our $AUTOLOAD;
+BEGIN { bytes::import() }
 
-sub AUTOLOAD {
-    require "bytes_heavy.pl";
-    goto &{Symbol::fetch_glob($AUTOLOAD)} if defined &{Symbol::fetch_glob($AUTOLOAD)};
-    require Carp;
-    Carp::croak("Undefined subroutine $AUTOLOAD called");
+sub length (_) {
+    return CORE::length($_[0]);
 }
 
-sub length (_);
-sub chr (_);
-sub ord (_);
-sub substr ($$;$$);
-sub index ($$;$);
-sub rindex ($$;$);
+sub substr ($$;$$) {
+    return
+	@_ == 2 ? CORE::substr($_[0], $_[1]) :
+	@_ == 3 ? CORE::substr($_[0], $_[1], $_[2]) :
+	          CORE::substr($_[0], $_[1], $_[2], $_[3]) ;
+}
+
+sub ord (_) {
+    return CORE::ord($_[0]);
+}
+
+sub chr (_) {
+    return CORE::chr($_[0]);
+}
+
+sub index ($$;$) {
+    return
+	@_ == 2 ? CORE::index($_[0], $_[1]) :
+	          CORE::index($_[0], $_[1], $_[2]) ;
+}
+
+sub rindex ($$;$) {
+    return
+	@_ == 2 ? CORE::rindex($_[0], $_[1]) :
+	          CORE::rindex($_[0], $_[1], $_[2]) ;
+}
+
+BEGIN { bytes::import() }
 
 1;
 __END__
