@@ -11,6 +11,7 @@ BEGIN {
 
 our $VERSION = '1.07';
 
+# toggle utf8/codepoints hints
 sub import {
     $^H ^|^= $utf8::hint_bits;
     $^H ^|^= $utf8::codepoints_hint_bits;
@@ -22,21 +23,50 @@ sub unimport {
     $^H ^&^= ^~^$utf8::codepoints_hint_bits;
 }
 
-our $AUTOLOAD;
-
-sub AUTOLOAD {
+# SWASHNEW
+sub SWASHNEW {
     require "utf8_heavy.pl";
-    goto &{Symbol::fetch_glob($AUTOLOAD)} if defined &{Symbol::fetch_glob($AUTOLOAD)};
-    require Carp;
-    Carp::croak("Undefined subroutine $AUTOLOAD called");
+    goto &utf8::SWASHNEW_real;
 }
 
-sub length (_);
-sub chr (_);
-sub ord (_);
-sub substr ($$;$$);
-sub index ($$;$);
-sub rindex ($$;$);
+# utf version of string functions
+
+sub length (_) {
+    BEGIN { utf8::import() }
+    return CORE::length($_[0]);
+}
+
+sub substr ($$;$$) {
+    BEGIN { utf8::import() }
+    return
+	@_ == 2 ? CORE::substr($_[0], $_[1]) :
+	@_ == 3 ? CORE::substr($_[0], $_[1], $_[2]) :
+	          CORE::substr($_[0], $_[1], $_[2], $_[3]) ;
+}
+
+sub ord (_) {
+    BEGIN { utf8::import() }
+    return CORE::ord($_[0]);
+}
+
+sub chr (_) {
+    BEGIN { utf8::import() }
+    return CORE::chr($_[0]);
+}
+
+sub index ($$;$) {
+    BEGIN { utf8::import() }
+    return
+	@_ == 2 ? CORE::index($_[0], $_[1]) :
+	          CORE::index($_[0], $_[1], $_[2]) ;
+}
+
+sub rindex ($$;$) {
+    BEGIN { utf8::import() }
+    return
+	@_ == 2 ? CORE::rindex($_[0], $_[1]) :
+	          CORE::rindex($_[0], $_[1], $_[2]) ;
+}
 
 1;
 __END__
