@@ -58,7 +58,9 @@ PERL_CALLCONV void Perl_sv_usepvn_mg(pTHX_ SV *sv, char *ptr, STRLEN len);
 PERL_CALLCONV void Perl_sv_usepvn(pTHX_ SV *sv, char *ptr, STRLEN len);
 PERL_CALLCONV int Perl_fprintf_nocontext(PerlIO *stream, const char *format, ...);
 PERL_CALLCONV int Perl_printf_nocontext(const char *format, ...);
-
+PERL_CALLCONV int Perl_magic_setglob(pTHX_ SV* sv, MAGIC* mg);
+PERL_CALLCONV AV * Perl_newAV(pTHX);
+PERL_CALLCONV HV * Perl_newHV(pTHX);
 
 /* ref() is now a macro using Perl_doref;
  * this version provided for binary compatibility only.
@@ -83,6 +85,8 @@ being zero.  See C<SvROK_off>.
 void
 Perl_sv_unref(pTHX_ SV *sv)
 {
+    PERL_ARGS_ASSERT_SV_UNREF;
+
     sv_unref_flags(sv, 0);
 }
 
@@ -96,6 +100,8 @@ Taint an SV. Use C<SvTAINTED_on> instead.
 void
 Perl_sv_taint(pTHX_ SV *sv)
 {
+    PERL_ARGS_ASSERT_SV_TAINT;
+
     sv_magic((sv), NULL, PERL_MAGIC_taint, NULL, 0);
 }
 
@@ -156,6 +162,8 @@ an xpvmg. See also C<sv_force_normal_flags>.
 void
 Perl_sv_force_normal(pTHX_ register SV *sv)
 {
+    PERL_ARGS_ASSERT_SV_FORCE_NORMAL;
+
     sv_force_normal_flags(sv, 0);
 }
 
@@ -166,6 +174,8 @@ Perl_sv_force_normal(pTHX_ register SV *sv)
 void
 Perl_sv_setsv(pTHX_ SV *dstr, register SV *sstr)
 {
+    PERL_ARGS_ASSERT_SV_SETSV;
+
     sv_setsv_flags(dstr, sstr, SV_GMAGIC);
 }
 
@@ -176,6 +186,8 @@ Perl_sv_setsv(pTHX_ SV *dstr, register SV *sstr)
 void
 Perl_sv_catpvn(pTHX_ SV *dsv, const char* sstr, STRLEN slen)
 {
+    PERL_ARGS_ASSERT_SV_CATPVN;
+
     sv_catpvn_flags(dsv, sstr, slen, SV_GMAGIC);
 }
 
@@ -190,6 +202,8 @@ Like C<sv_catpvn>, but also handles 'set' magic.
 void
 Perl_sv_catpvn_mg(pTHX_ register SV *sv, register const char *ptr, register STRLEN len)
 {
+    PERL_ARGS_ASSERT_SV_CATPVN_MG;
+
     sv_catpvn_flags(sv,ptr,len,SV_GMAGIC|SV_SMAGIC);
 }
 
@@ -200,6 +214,8 @@ Perl_sv_catpvn_mg(pTHX_ register SV *sv, register const char *ptr, register STRL
 void
 Perl_sv_catsv(pTHX_ SV *dstr, register SV *sstr)
 {
+    PERL_ARGS_ASSERT_SV_CATSV;
+
     sv_catsv_flags(dstr, sstr, SV_GMAGIC);
 }
 
@@ -214,6 +230,8 @@ Like C<sv_catsv>, but also handles 'set' magic.
 void
 Perl_sv_catsv_mg(pTHX_ SV *dsv, register SV *ssv)
 {
+    PERL_ARGS_ASSERT_SV_CATSV_MG;
+
     sv_catsv_flags(dsv,ssv,SV_GMAGIC|SV_SMAGIC);
 }
 
@@ -229,6 +247,8 @@ cope with complex macro expressions. Always use the macro instead.
 IV
 Perl_sv_iv(pTHX_ register SV *sv)
 {
+    PERL_ARGS_ASSERT_SV_IV;
+
     if (SvIOK(sv)) {
 	if (SvIsUV(sv))
 	    return (IV)SvUVX(sv);
@@ -249,6 +269,8 @@ cope with complex macro expressions. Always use the macro instead.
 UV
 Perl_sv_uv(pTHX_ register SV *sv)
 {
+    PERL_ARGS_ASSERT_SV_UV;
+
     if (SvIOK(sv)) {
 	if (SvIsUV(sv))
 	    return SvUVX(sv);
@@ -269,6 +291,8 @@ cope with complex macro expressions. Always use the macro instead.
 NV
 Perl_sv_nv(pTHX_ register SV *sv)
 {
+    PERL_ARGS_ASSERT_SV_NV;
+
     if (SvNOK(sv))
 	return SvNVX(sv);
     return sv_2nv(sv);
@@ -290,6 +314,8 @@ cope with complex macro expressions. Always use the macro instead.
 char *
 Perl_sv_pvn(pTHX_ SV *sv, STRLEN *lp)
 {
+    PERL_ARGS_ASSERT_SV_PVN;
+
     if (SvPOK(sv)) {
 	*lp = SvCUR(sv);
 	return SvPVX(sv);
@@ -301,6 +327,8 @@ Perl_sv_pvn(pTHX_ SV *sv, STRLEN *lp)
 char *
 Perl_sv_pvn_nomg(pTHX_ register SV *sv, STRLEN *lp)
 {
+    PERL_ARGS_ASSERT_SV_PVN_NOMG;
+
     if (SvPOK(sv)) {
 	*lp = SvCUR(sv);
 	return SvPVX(sv);
@@ -315,6 +343,8 @@ Perl_sv_pvn_nomg(pTHX_ register SV *sv, STRLEN *lp)
 char *
 Perl_sv_pv(pTHX_ SV *sv)
 {
+    PERL_ARGS_ASSERT_SV_PV;
+
     if (SvPOK(sv))
         return SvPVX(sv);
 
@@ -328,6 +358,8 @@ Perl_sv_pv(pTHX_ SV *sv)
 char *
 Perl_sv_pvn_force(pTHX_ SV *sv, STRLEN *lp)
 {
+    PERL_ARGS_ASSERT_SV_PVN_FORCE;
+
     return sv_pvn_force_flags(sv, lp, SV_GMAGIC);
 }
 
@@ -336,6 +368,13 @@ Perl_fprintf_nocontext(PerlIO *stream, const char *format, ...)
 {
     dTHXs;
     va_list(arglist);
+
+    /* Easier to special case this here than in embed.pl. (Look at what it
+       generates for proto.h) */
+#ifdef PERL_IMPLICIT_CONTEXT
+    PERL_ARGS_ASSERT_FPRINTF_NOCONTEXT;
+#endif
+
     va_start(arglist, format);
     return PerlIO_vprintf(stream, format, arglist);
 }
@@ -345,6 +384,11 @@ Perl_printf_nocontext(const char *format, ...)
 {
     dTHX;
     va_list(arglist);
+
+#ifdef PERL_IMPLICIT_CONTEXT
+    PERL_ARGS_ASSERT_PRINTF_NOCONTEXT;
+#endif
+
     va_start(arglist, format);
     return PerlIO_vprintf(PerlIO_stdout(), format, arglist);
 }
@@ -369,12 +413,16 @@ Perl_huge(void)
 HE *
 Perl_hv_iternext(pTHX_ HV *hv)
 {
+    PERL_ARGS_ASSERT_HV_ITERNEXT;
+
     return hv_iternext_flags(hv, 0);
 }
 
 void
 Perl_hv_magic(pTHX_ HV *hv, GV *gv, int how)
 {
+    PERL_ARGS_ASSERT_HV_MAGIC;
+
     sv_magic((SV*)hv, (SV*)gv, how, NULL, 0);
 }
 
@@ -383,6 +431,9 @@ Perl_av_fake(pTHX_ register I32 size, register SV **strp)
 {
     register SV** ary;
     register AV * const av = (AV*)newSV_type(SVt_PVAV);
+
+    PERL_ARGS_ASSERT_AV_FAKE;
+
     Newx(ary,size+1,SV*);
     AvALLOC(av) = ary;
     Copy(strp,ary,size,SV*);
@@ -402,6 +453,8 @@ bool
 Perl_do_open(pTHX_ GV *gv, register const char *name, I32 len, int as_raw,
 	     int rawmode, int rawperm, PerlIO *supplied_fp)
 {
+    PERL_ARGS_ASSERT_DO_OPEN;
+
     return do_openn(gv, name, len, as_raw, rawmode, rawperm,
 		    supplied_fp, (SV **) NULL, 0);
 }
@@ -412,6 +465,8 @@ as_raw,
               int rawmode, int rawperm, PerlIO *supplied_fp, SV *svs,
               I32 num_svs)
 {
+    PERL_ARGS_ASSERT_DO_OPEN9;
+
     PERL_UNUSED_ARG(num_svs);
     return do_openn(gv, name, len, as_raw, rawmode, rawperm,
                     supplied_fp, &svs, 1);
@@ -424,6 +479,9 @@ Perl_do_binmode(pTHX_ PerlIO *fp, int iotype, int mode)
   * This is a stub for any XS code which might have been calling it.
   */
  const char *name = ":raw";
+
+ PERL_ARGS_ASSERT_DO_BINMODE;
+
 #ifdef PERLIO_USING_CRLF
  if (!(mode & O_BINARY))
      name = ":crlf";
@@ -435,6 +493,8 @@ Perl_do_binmode(pTHX_ PerlIO *fp, int iotype, int mode)
 bool
 Perl_do_aexec(pTHX_ SV *really, register SV **mark, register SV **sp)
 {
+    PERL_ARGS_ASSERT_DO_AEXEC;
+
     return do_aexec5(really, mark, sp, 0, 0);
 }
 #endif
@@ -443,6 +503,8 @@ Perl_do_aexec(pTHX_ SV *really, register SV **mark, register SV **sp)
 bool
 Perl_do_exec(pTHX_ const char *cmd)
 {
+    PERL_ARGS_ASSERT_DO_EXEC;
+
     return do_exec3(cmd,0,0);
 }
 #endif
@@ -450,6 +512,8 @@ Perl_do_exec(pTHX_ const char *cmd)
 OP *
 Perl_oopsCV(pTHX_ OP *o)
 {
+    PERL_ARGS_ASSERT_OOPSCV;
+
     Perl_croak(aTHX_ "NOT IMPL LINE %d",__LINE__);
     /* STUB */
     PERL_UNUSED_ARG(o);
@@ -814,21 +878,6 @@ PP(pp_lcfirst)
     return pp_ucfirst();
 }
 
-PP(pp_slt)
-{
-    return pp_sle();
-}
-
-PP(pp_sgt)
-{
-    return pp_sle();
-}
-
-PP(pp_sge)
-{
-    return pp_sle();
-}
-
 PP(pp_rindex)
 {
     return pp_index();
@@ -877,12 +926,16 @@ PP(pp_rv2hv)
 char *
 Perl_uvuni_to_utf8(pTHX_ char *d, UV uv)
 {
+    PERL_ARGS_ASSERT_UVUNI_TO_UTF8;
+
     return Perl_uvuni_to_utf8_flags(aTHX_ d, uv, 0);
 }
 
 bool
 Perl_is_utf8_string_loc(pTHX_ const char *s, STRLEN len, const char **ep)
 {
+    PERL_ARGS_ASSERT_IS_UTF8_STRING_LOC;
+
     return is_utf8_string_loclen(s, len, ep, 0);
 }
 
@@ -929,6 +982,9 @@ void
 Perl_save_long(pTHX_ long int *longp)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_SAVE_LONG;
+
     SSCHECK(3);
     SSPUSHLONG(*longp);
     SSPUSHPTR(longp);
@@ -939,6 +995,9 @@ void
 Perl_save_iv(pTHX_ IV *ivp)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_SAVE_IV;
+
     SSCHECK(3);
     SSPUSHIV(*ivp);
     SSPUSHPTR(ivp);
@@ -949,6 +1008,9 @@ void
 Perl_save_nogv(pTHX_ GV *gv)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_SAVE_NOGV;
+
     SSCHECK(2);
     SSPUSHPTR(gv);
     SSPUSHINT(SAVEt_NSTAB);
@@ -960,6 +1022,8 @@ Perl_save_list(pTHX_ register SV **sarg, I32 maxsarg)
     dVAR;
     register I32 i;
 
+    PERL_ARGS_ASSERT_SAVE_LIST;
+
     for (i = 1; i <= maxsarg; i++) {
 	register SV * const sv = newSV(0);
 	sv_setsv(sv,sarg[i]);
@@ -981,6 +1045,8 @@ Like C<sv_usepvn>, but also handles 'set' magic.
 void
 Perl_sv_usepvn_mg(pTHX_ SV *sv, char *ptr, STRLEN len)
 {
+    PERL_ARGS_ASSERT_SV_USEPVN_MG;
+
     sv_usepvn_flags(sv,ptr,len, SV_SMAGIC);
 }
 
@@ -997,12 +1063,16 @@ magic. See C<sv_usepvn_flags>.
 void
 Perl_sv_usepvn(pTHX_ SV *sv, char *ptr, STRLEN len)
 {
+    PERL_ARGS_ASSERT_SV_USEPVN;
+
     sv_usepvn_flags(sv,ptr,len, 0);
 }
 
 void
 Perl_cv_ckproto(pTHX_ const CV *cv, const GV *gv, const char *p)
 {
+    PERL_ARGS_ASSERT_CV_CKPROTO;
+
     cv_ckproto_len(cv, gv, p, p ? strlen(p) : 0);
 }
 
@@ -1019,6 +1089,8 @@ Perl_unpack_str(pTHX_ const char *pat, const char *patend, const char *s,
 		const char *strbeg, const char *strend, char **new_s, I32 ocnt,
 		U32 flags)
 {
+    PERL_ARGS_ASSERT_UNPACK_STR;
+
     PERL_UNUSED_ARG(strbeg);
     PERL_UNUSED_ARG(new_s);
     PERL_UNUSED_ARG(ocnt);
@@ -1038,6 +1110,8 @@ flags are not used. This call should not be used; use packlist instead.
 void
 Perl_pack_cat(pTHX_ SV *cat, const char *pat, const char *patend, register SV **beglist, SV **endlist, SV ***next_in_list, U32 flags)
 {
+    PERL_ARGS_ASSERT_PACK_CAT;
+
     PERL_UNUSED_ARG(next_in_list);
     PERL_UNUSED_ARG(flags);
 
@@ -1053,6 +1127,8 @@ Perl_hv_store_ent(pTHX_ HV *hv, SV *keysv, SV *val, U32 hash)
 bool
 Perl_hv_exists_ent(pTHX_ HV *hv, SV *keysv, U32 hash)
 {
+    PERL_ARGS_ASSERT_HV_EXISTS_ENT;
+
     return hv_common(hv, keysv, NULL, 0, 0, HV_FETCH_ISEXISTS, 0, hash)
 	? TRUE : FALSE;
 }
@@ -1060,6 +1136,8 @@ Perl_hv_exists_ent(pTHX_ HV *hv, SV *keysv, U32 hash)
 HE *
 Perl_hv_fetch_ent(pTHX_ HV *hv, SV *keysv, I32 lval, U32 hash)
 {
+    PERL_ARGS_ASSERT_HV_FETCH_ENT;
+
     return (HE *)hv_common(hv, keysv, NULL, 0, 0, 
 		     (lval ? HV_FETCH_LVALUE : 0), NULL, hash);
 }
@@ -1067,6 +1145,8 @@ Perl_hv_fetch_ent(pTHX_ HV *hv, SV *keysv, I32 lval, U32 hash)
 SV *
 Perl_hv_delete_ent(pTHX_ HV *hv, SV *keysv, I32 flags, U32 hash)
 {
+    PERL_ARGS_ASSERT_HV_DELETE_ENT;
+
     return (SV *) hv_common(hv, keysv, NULL, 0, 0, flags | HV_DELETE, NULL,
 			    hash);
 }
@@ -1097,8 +1177,11 @@ Perl_hv_exists(pTHX_ HV *hv, const char *key, I32 klen_i32)
     STRLEN klen;
     int flags;
 
+    PERL_ARGS_ASSERT_HV_EXISTS;
+
     klen = klen_i32;
     flags = 0;
+
     return hv_common(hv, NULL, key, klen, flags, HV_FETCH_ISEXISTS, 0, 0)
 	? TRUE : FALSE;
 }
@@ -1109,6 +1192,8 @@ Perl_hv_fetch(pTHX_ HV *hv, const char *key, I32 klen_i32, I32 lval)
     STRLEN klen;
     int flags;
 
+    PERL_ARGS_ASSERT_HV_FETCH;
+
     klen = klen_i32;
     flags = 0;
     return (SV **) hv_common(hv, NULL, key, klen, flags,
@@ -1122,12 +1207,45 @@ Perl_hv_delete(pTHX_ HV *hv, const char *key, I32 klen_i32, I32 flags)
     STRLEN klen;
     int k_flags;
 
+    PERL_ARGS_ASSERT_HV_DELETE;
+
     klen = klen_i32;
     k_flags = 0;
     return (SV *) hv_common(hv, NULL, key, klen, k_flags, flags | HV_DELETE,
 			    NULL, 0);
 }
 
+/* Functions after here were made mathoms post 5.10.0 but pre 5.8.9 */
+int
+Perl_magic_setglob(pTHX_ SV *sv, MAGIC *mg)
+{
+    PERL_UNUSED_ARG(mg);
+    PERL_UNUSED_ARG(sv);
+
+    Perl_croak(aTHX_ "Perl_magic_setglob is dead code?");
+
+    return 0;
+}
+
+AV *
+Perl_newAV(pTHX)
+{
+    return (AV*)newSV_type(SVt_PVAV);
+    /* sv_upgrade does AvREAL_only():
+    AvALLOC(av) = 0;
+    AvARRAY(av) = NULL;
+    AvMAX(av) = AvFILLp(av) = -1; */
+}
+
+HV *
+Perl_newHV(pTHX)
+{
+    HV * const hv = (HV*)newSV_type(SVt_PVHV);
+    assert(!SvOK(hv));
+
+    return hv;
+}
+
 #endif /* NO_MATHOMS */
 
 /*
