@@ -1,5 +1,6 @@
 #!/usr/bin/perl -w
 use strict;
+use kurila;
 
 BEGIN {
     # Get function prototypes
@@ -17,7 +18,7 @@ select OC;
 # Read data.
 
 my %seen;
-my (@ops, %desc, %check, %ckname, %flags, %args);
+my (@ops, %desc, %check, %ckname, %flags, %args, %opnum);
 
 while ( ~< *DATA) {
     chop;
@@ -32,6 +33,7 @@ while ( ~< *DATA) {
     $seen{$key} = qq[opcode "$key"];
 
     push(@ops, $key);
+    $opnum{$key} = $#ops;
     $desc{$key} = $desc;
     $check{$key} = $check;
     $ckname{$check}++;
@@ -146,7 +148,8 @@ END
 
 my $i = 0;
 for (@ops) {
-    print ON "\t", &tab(3,"OP_\U$_,"), "/* ", $i++, " */\n";
+    # print ON "\t", &tab(3,"OP_\U$_,"), "/* ", $i++, " */\n";
+      print ON "\t", &tab(3,"OP_\U$_"), " = ", $i++, ",\n";
 }
 print ON "\t", &tab(3,"OP_max"), "\n";
 print ON "\} opcode;\n";
@@ -288,6 +291,8 @@ END
 
 # Emit allowed argument types.
 
+my $ARGBITS = 32;
+
 print <<END;
 #ifndef PERL_GLOBAL_STRUCT_INIT
 
@@ -324,39 +329,57 @@ my %opclass = (
     '}',  13,		# loopexop
 );
 
+my %opflags = (
+    'm' =>   1,		# needs stack mark
+    'f' =>   2,		# fold constants
+    's' =>   4,		# always produces scalar
+    't' =>   8,		# needs target scalar
+    'T' =>   8 ^|^ 256,	# ... which may be lexical
+    'i' =>  16,		# always produces integer
+    'I' =>  32,		# has corresponding int op
+    'd' =>  64,		# danger, unknown side effects
+    'u' => 128,		# defaults to $_
+);
+
 my %OP_IS_SOCKET;
 my %OP_IS_FILETEST;
+my %OP_IS_FT_ACCESS;
+my $OCSHIFT = 9;
+my $OASHIFT = 13;
 
-for (@ops) {
+for my $op (@ops) {
     my $argsum = 0;
-    my $flags = $flags{$_};
-    $argsum ^|^= 1 if $flags =~ m/m/;		# needs stack mark
-    $argsum ^|^= 2 if $flags =~ m/f/;		# fold constants
-    $argsum ^|^= 4 if $flags =~ m/s/;		# always produces scalar
-    $argsum ^|^= 8 if $flags =~ m/t/;		# needs target scalar
-    $argsum ^|^= (8^|^256) if $flags =~ m/T/;	# ... which may be lexical
-    $argsum ^|^= 16 if $flags =~ m/i/;		# always produces integer
-    $argsum ^|^= 32 if $flags =~ m/I/;		# has corresponding int op
-    $argsum ^|^= 64 if $flags =~ m/d/;		# danger, unknown side effects
-    $argsum ^|^= 128 if $flags =~ m/u/;		# defaults to $_
-    $flags =~ m/([\W\d_])/ or die qq[Opcode "$_" has no class indicator];
-    $argsum ^|^= $opclass{$1} << 9;
-    my $mul = 0x2000;				# 2 ^ OASHIFT
-    for my $arg (split(' ',$args{$_})) {
+    my $flags = $flags{$op};
+    for my $flag (keys %opflags) {
+	if ($flags =~ s/$flag//) {
+	    die "Flag collision for '$op' ($flags{$op}, $flag)"
+		if $argsum ^&^ $opflags{$flag};
+	    $argsum ^|^= $opflags{$flag};
+	}
+    }
+    die qq[Opcode '$op' has no class indicator ($flags{$op} => $flags)]
+	unless exists $opclass{$flags};
+    $argsum ^|^= $opclass{$flags} << $OCSHIFT;
+    my $argshift = $OASHIFT;
+    for my $arg (split(' ',$args{$op})) {
 	if ($arg =~ m/^F/) {
-           $OP_IS_SOCKET{$_}   = 1 if $arg =~ s/s//;
-           $OP_IS_FILETEST{$_} = 1 if $arg =~ s/-//;
+	    # record opnums of these opnames
+	    $OP_IS_SOCKET{$op}   = $opnum{$op} if $arg =~ s/s//;
+	    $OP_IS_FILETEST{$op} = $opnum{$op} if $arg =~ s/-//;
+	    $OP_IS_FT_ACCESS{$op} = $opnum{$op} if $arg =~ s/\+//;
         }
 	my $argnum = ($arg =~ s/\?//) ? 8 : 0;
-        die "op = $_, arg = $arg\n" unless length($arg) == 1;
+        die "op = $op, arg = $arg\n"
+	    unless exists $argnum{$arg};
 	$argnum += $argnum{$arg};
-	warn "# Conflicting bit 32 for '$_'.\n"
-	    if $argnum ^&^ 8 and $mul == 0x10000000;
-	$argsum += $argnum * $mul;
-	$mul <<= 4;
+	die "Argument overflow for '$op'\n"
+	    if $argshift +>= $ARGBITS ||
+	       $argnum +> ((1 << ($ARGBITS - $argshift)) - 1);
+	$argsum += $argnum << $argshift;
+	$argshift += 4;
     }
     $argsum = sprintf("0x%08x", $argsum);
-    print "\t", &tab(3, "$argsum,"), "/* $_ */\n";
+    print "\t", &tab(3, "$argsum,"), "/* $op */\n";
 }
 
 print <<END;
@@ -369,18 +392,48 @@ END_EXTERN_C
 
 END
 
-if (keys %OP_IS_SOCKET) {
-    print ON "\n#define OP_IS_SOCKET(op)	\\\n\t(";
-    print ON join(" || \\\n\t ",
-               map { "(op) == OP_" . uc() } sort keys %OP_IS_SOCKET);
-    print ON ")\n\n";
-}
+# Emit OP_IS_* macros
 
-if (keys %OP_IS_FILETEST) {
-    print ON "\n#define OP_IS_FILETEST(op)	\\\n\t(";
-    print ON join(" || \\\n\t ",
-               map { "(op) == OP_" . uc() } sort keys %OP_IS_FILETEST);
-    print ON ")\n\n";
+print ON <<EO_OP_IS_COMMENT;
+
+/* the OP_IS_(SOCKET|FILETEST) macros are optimized to a simple range
+    check because all the member OPs are contiguous in opcode.pl
+    <DATA> table.  opcode.pl verifies the range contiguity.  */
+
+EO_OP_IS_COMMENT
+
+gen_op_is_macro( \%OP_IS_SOCKET, 'OP_IS_SOCKET');
+gen_op_is_macro( \%OP_IS_FILETEST, 'OP_IS_FILETEST');
+gen_op_is_macro( \%OP_IS_FT_ACCESS, 'OP_IS_FILETEST_ACCESS');
+
+sub gen_op_is_macro {
+    my ($op_is, $macname) = @_;
+    if (keys %$op_is) {
+	
+	# get opnames whose numbers are lowest and highest
+	my ($first, @rest) = sort {
+	    $op_is->{$a} <+> $op_is->{$b}
+	} keys %$op_is;
+	
+	my $last = pop @rest;	# @rest slurped, get its last
+	die "invalid range of ops: $first .. $last" unless $last;
+
+	print ON "#define $macname(op)	\\\n\t(";
+
+	# verify that op-ct matches 1st..last range (and fencepost)
+	# (we know there are no dups)
+	if ( $op_is->{$last} - $op_is->{$first} == scalar @rest + 1) {
+	    
+	    # contiguous ops -> optimized version
+	    print ON "(op) >= OP_" . uc($first) . " && (op) <= OP_" . uc($last);
+	    print ON ")\n\n";
+	}
+	else {
+	    print ON join(" || \\\n\t ",
+			  map { "(op) == OP_" . uc() } sort keys %$op_is);
+	    print ON ")\n\n";
+	}
+    }
 }
 
 print OC "/* ex: set ro: */\n";
@@ -552,7 +605,9 @@ __END__
 # Values for the operands are:
 # scalar      - S            list     - L            array     - A
 # hash        - H            sub (CV) - C            file      - F
-# socket      - Fs           filetest - F-           reference - R
+# socket      - Fs           filetest - F-           filetest_access - F-+
+
+# reference - R
 # "?" denotes an optional operand.
 
 # Nothing.
@@ -671,10 +726,6 @@ i_ne		integer ne (!=)		ck_null		ifs2	S S
 ncmp		numeric comparison (<+>)	ck_null		Iifst2	S S
 i_ncmp		integer comparison (<+>)	ck_null		ifst2	S S
 
-slt		string lt		ck_null		ifs2	S S
-sgt		string gt		ck_null		ifs2	S S
-sle		string le		ck_null		ifs2	S S
-sge		string ge		ck_null		ifs2	S S
 seq		string eq		ck_null		ifs2	S S
 sne		string ne		ck_null		ifs2	S S
 scmp		string comparison (cmp)	ck_null		ifst2	S S
@@ -710,7 +761,7 @@ abs		abs			ck_fun		fsTu%	S?
 
 # String stuff.
 
-length		length			ck_lengthconst	isTu%	S?
+length		length			ck_fun		ifsTu%	S?
 substr		substr			ck_substr	st@	S S S? S?
 vec		vec			ck_fun		ist@	S S S
 
@@ -742,7 +793,7 @@ keys		keys			ck_fun		t%	H
 delete		delete			ck_delete	%	S
 exists		exists			ck_exists	is%	S
 rv2hv		hash dereference	ck_rvconst	dt1	
-helem		hash element		ck_null		s2@	H S
+helem		hash element		ck_null		s2	H S
 hslice		hash slice		ck_null		m@	H L
 
 # Explosives and implosives.
@@ -816,7 +867,6 @@ redo		redo			ck_null		ds}
 dump		dump			ck_null		ds}	
 goto		goto			ck_null		ds}	
 exit		exit			ck_exit		ds%	S?
-setstate	set statement info	ck_null		s;
 method_named	method with known name	ck_null		d$
 
 entergiven	given()			ck_null		d|
@@ -854,9 +904,6 @@ sysseek		sysseek			ck_fun		s@	F S S
 sysread		sysread			ck_fun		imst@	F R S S?
 syswrite	syswrite		ck_fun		imst@	F S S? S?
 
-send		send			ck_fun		imst@	Fs S S S?
-recv		recv			ck_fun		imst@	Fs R S S
-
 eof		eof			ck_eof		is%	F?
 tell		tell			ck_fun		st%	F?
 seek		seek			ck_fun		s@	F S S
@@ -867,7 +914,10 @@ fcntl		fcntl			ck_fun		st@	F S S
 ioctl		ioctl			ck_fun		st@	F S S
 flock		flock			ck_fun		isT@	F S
 
-# Sockets.
+# Sockets.  OP_IS_SOCKET wants them consecutive (so moved 1st 2)
+
+send		send			ck_fun		imst@	Fs S S S?
+recv		recv			ck_fun		imst@	Fs R S S
 
 socket		socket			ck_fun		is@	Fs S S S
 sockpair	socketpair		ck_fun		is@	Fs Fs S S S
@@ -884,16 +934,16 @@ ssockopt	setsockopt		ck_fun		is@	Fs S S S
 getsockname	getsockname		ck_fun		is%	Fs
 getpeername	getpeername		ck_fun		is%	Fs
 
-# Stat calls.
+# Stat calls.  OP_IS_FILETEST wants them consecutive.
 
 lstat		lstat			ck_ftst		u-	F
 stat		stat			ck_ftst		u-	F
-ftrread		-R			ck_ftst		isu-	F-
-ftrwrite	-W			ck_ftst		isu-	F-
-ftrexec		-X			ck_ftst		isu-	F-
-fteread		-r			ck_ftst		isu-	F-
-ftewrite	-w			ck_ftst		isu-	F-
-fteexec		-x			ck_ftst		isu-	F-
+ftrread		-R			ck_ftst		isu-	F-+
+ftrwrite	-W			ck_ftst		isu-	F-+
+ftrexec		-X			ck_ftst		isu-	F-+
+fteread		-r			ck_ftst		isu-	F-+
+ftewrite	-w			ck_ftst		isu-	F-+
+fteexec		-x			ck_ftst		isu-	F-+
 ftis		-e			ck_ftst		isu-	F-
 ftsize		-s			ck_ftst		istu-	F-
 ftmtime		-M			ck_ftst		stu-	F-
@@ -992,6 +1042,7 @@ semctl		semctl			ck_fun		imst@	S S S S
 
 require		require			ck_require	du%	S?
 dofile		do "file"		ck_fun		d1	S
+hintseval	eval hints		ck_svconst	s$
 entereval	eval "string"		ck_eval		d%	S
 leaveeval	eval "string" exit	ck_null		1	S
 #evalonce	eval constant string	ck_null		d1	S
