@@ -66,50 +66,58 @@ typedef struct regexp_paren_pair {
   regexp's data array based on the data item's type.
 */
 
+#define _REGEXP_COMMON							\
+        /* what engine created this regexp? */				\
+	const struct regexp_engine* engine; 				\
+	REGEXP *mother_re; /* what re is this a lightweight copy of? */	\
+	/* Information about the match that the perl core uses to */	\
+	/* manage things */						\
+	U32 extflags;	/* Flags used both externally and internally */	\
+	I32 minlen;	/* mininum possible length of string to match */\
+	I32 minlenret;	/* mininum possible length of $& */		\
+	U32 gofs;	/* chars left of pos that we search from */	\
+	/* substring data about strings that must appear in the */	\
+	/* final match, used for optimisations */			\
+	struct reg_substr_data *substrs;				\
+	U32 nparens;	/* number of capture buffers */			\
+	/* private engine specific data */				\
+	U32 intflags;	/* Engine Specific Internal flags */		\
+	void *pprivate;	/* Data private to the regex engine which */	\
+			/* created this object. */			\
+	/* Data about the last/current match. These are modified */	\
+	/* during matching */						\
+	U32 lastparen;			/* last open paren matched */	\
+	U32 lastcloseparen;		/* last close paren matched */	\
+	regexp_paren_pair *swap;	/* Swap copy of *offs */	\
+	/* Array of offsets for (@-) and (@+) */			\
+	regexp_paren_pair *offs;					\
+	/* saved or original string so \digit works forever. */		\
+	char *subbeg;							\
+	SV_SAVED_COPY	/* If non-NULL, SV which is COW from original */\
+	I32 sublen;	/* Length of string pointed by subbeg */	\
+	/* Information about the match that isn't often used */		\
+	/* offset from wrapped to the start of precomp */		\
+	PERL_BITFIELD32 pre_prefix:4;					\
+	/* number of eval groups in the pattern - for security checks */\
+	PERL_BITFIELD32 seen_evals:28
+
 typedef struct regexp {
-        /* what engine created this regexp? */
-	const struct regexp_engine* engine; 
-	struct regexp* mother_re; /* what re is this a lightweight copy of? */
-	
-	/* Information about the match that the perl core uses to manage things */
-	U32 extflags;           /* Flags used both externally and internally */
-	I32 minlen;		/* mininum possible length of string to match */
-	I32 minlenret;		/* mininum possible length of $& */
-	U32 gofs;               /* chars left of pos that we search from */
-	struct reg_substr_data *substrs; /* substring data about strings that must appear
-                                   in the final match, used for optimisations */
-	U32 nparens;		/* number of capture buffers */
-
-        /* private engine specific data */
-	U32 intflags;		/* Engine Specific Internal flags */
-	void *pprivate;         /* Data private to the regex engine which 
-                                   created this object. */
-        
-        /* Data about the last/current match. These are modified during matching*/
-        U32 lastparen;		/* last open paren matched */
-	U32 lastcloseparen;	/* last close paren matched */
-        regexp_paren_pair *swap;  /* Swap copy of *offs */ 
-        regexp_paren_pair *offs;  /* Array of offsets for (@-) and (@+) */
-
-	char *subbeg;		/* saved or original string 
-				   so \digit works forever. */
-	SV_SAVED_COPY           /* If non-NULL, SV which is COW from original */
-	I32 sublen;		/* Length of string pointed by subbeg */
-        
-        
-        /* Information about the match that isn't often used */
-	I32 prelen;		/* length of precomp */
-	const char *precomp;	/* pre-compilation regular expression */
-	/* wrapped can't be const char*, as it is returned by sv_2pv_flags */
-	char *wrapped;          /* wrapped version of the pattern */
-	I32 wraplen;		/* length of wrapped */
-	I32 seen_evals;         /* number of eval groups in the pattern - for security checks */ 
-        HV *paren_names;	/* Optional hash of paren names */
-        
-        /* Refcount of this regexp */
-	I32 refcnt;             /* Refcount of this regexp */
+	_XPV_HEAD;
+	_XPVMG_HEAD;
+	_REGEXP_COMMON;
 } regexp;
 
+struct regexp_allocated {
+	_XPV_ALLOCATED_HEAD;
+	_XPVMG_HEAD;
+	_REGEXP_COMMON;
+};
+
+/*        HV *paren_names;	 Optional hash of paren names
+	  now stored in the IV union */
+
+#define RXp_PAREN_NAMES(rx)	((rx)->xiv_u.xivu_hv)
+
 /* used for high speed searches */
 typedef struct re_scream_pos_data_s
 {
@@ -121,7 +129,7 @@ typedef struct re_scream_pos_data_s
  * Any regex engine implementation must be able to build one of these.
  */
 typedef struct regexp_engine {
-    REGEXP* (*comp) (pTHX_ const SV * const pattern, const U32 flags);
+    REGEXP* (*comp) (pTHX_ const SV * const pattern, U32 flags);
     I32     (*exec) (pTHX_ REGEXP * const rx, char* stringarg, char* strend,
                      char* strbeg, I32 minend, SV* screamer,
                      void* data, U32 flags);
@@ -245,7 +253,9 @@ and check for NULL.
 #define RXf_START_ONLY		0x00000200 /* Pattern is /^/ */
 #define RXf_WHITE		0x00000400 /* Pattern is /\s+/ */
 
-/* 0x1F800 of extflags is used by (RXf_)PMf_COMPILETIME */
+/* 0x1F800 of extflags is used by (RXf_)PMf_COMPILETIME
+ * If you change these you need to change the equivalent flags in op.h, and
+ * vice versa.  */
 #define RXf_PMf_MULTILINE	0x00001000 /* /m         */
 #define RXf_PMf_SINGLELINE	0x00002000 /* /s         */
 #define RXf_PMf_FOLD    	0x00004000 /* /i         */
@@ -253,6 +263,7 @@ and check for NULL.
 #define RXf_PMf_UTF8            0x00010000 /* /u         */
 #define RXf_PMf_KEEPCOPY	0x00020000 /* /p         */
 /* these flags are transfered from the PMOP->op_pmflags member during compilation */
+#define RXf_PMf_STD_PMMOD_SHIFT	12
 #define RXf_PMf_STD_PMMOD	(RXf_PMf_MULTILINE|RXf_PMf_SINGLELINE|RXf_PMf_FOLD|RXf_PMf_EXTENDED|RXf_PMf_UTF8)
 #define RXf_PMf_COMPILETIME	(RXf_PMf_MULTILINE|RXf_PMf_SINGLELINE|RXf_PMf_FOLD|RXf_PMf_EXTENDED|RXf_PMf_KEEPCOPY|RXf_PMf_UTF8)
 
@@ -327,44 +338,108 @@ and check for NULL.
  */
 
 #define RX_HAS_CUTGROUP(prog) ((prog)->intflags & PREGf_CUTGROUP_SEEN)
-#define RX_MATCH_TAINTED(prog)	((prog)->extflags & RXf_TAINTED_SEEN)
-#define RX_MATCH_TAINTED_on(prog) ((prog)->extflags |= RXf_TAINTED_SEEN)
-#define RX_MATCH_TAINTED_off(prog) ((prog)->extflags &= ~RXf_TAINTED_SEEN)
+#define RXp_MATCH_TAINTED(prog)	(RXp_EXTFLAGS(prog) & RXf_TAINTED_SEEN)
+#define RX_MATCH_TAINTED(prog)	(RX_EXTFLAGS(prog) & RXf_TAINTED_SEEN)
+#define RX_MATCH_TAINTED_on(prog) (RX_EXTFLAGS(prog) |= RXf_TAINTED_SEEN)
+#define RX_MATCH_TAINTED_off(prog) (RX_EXTFLAGS(prog) &= ~RXf_TAINTED_SEEN)
 #define RX_MATCH_TAINTED_set(prog, t) ((t) \
 				       ? RX_MATCH_TAINTED_on(prog) \
 				       : RX_MATCH_TAINTED_off(prog))
 
-#define RX_MATCH_COPIED(prog)		((prog)->extflags & RXf_COPY_DONE)
-#define RX_MATCH_COPIED_on(prog)	((prog)->extflags |= RXf_COPY_DONE)
-#define RX_MATCH_COPIED_off(prog)	((prog)->extflags &= ~RXf_COPY_DONE)
+#define RXp_MATCH_COPIED(prog)		(RXp_EXTFLAGS(prog) & RXf_COPY_DONE)
+#define RX_MATCH_COPIED(prog)		(RX_EXTFLAGS(prog) & RXf_COPY_DONE)
+#define RXp_MATCH_COPIED_on(prog)	(RXp_EXTFLAGS(prog) |= RXf_COPY_DONE)
+#define RX_MATCH_COPIED_on(prog)	(RX_EXTFLAGS(prog) |= RXf_COPY_DONE)
+#define RXp_MATCH_COPIED_off(prog)	(RXp_EXTFLAGS(prog) &= ~RXf_COPY_DONE)
+#define RX_MATCH_COPIED_off(prog)	(RX_EXTFLAGS(prog) &= ~RXf_COPY_DONE)
 #define RX_MATCH_COPIED_set(prog,t)	((t) \
 					 ? RX_MATCH_COPIED_on(prog) \
 					 : RX_MATCH_COPIED_off(prog))
 
+#define RXp_EXTFLAGS(rx)	((rx)->extflags)
+
+/* For source compatibility. We used to store these explicitly.  */
+#define RX_PRECOMP(prog)	(RX_WRAPPED(prog) + ((struct regexp *)SvANY(prog))->pre_prefix)
+/* FIXME? Are we hardcoding too much here and constraining plugin extension
+   writers? Specifically, the value 1 assumes that the wrapped version always
+   has exactly one character at the end, a ')'. Will that always be true?  */
+#define RX_PRELEN(prog)		(RX_WRAPLEN(prog) - ((struct regexp *)SvANY(prog))->pre_prefix - 1)
+#define RX_WRAPPED(prog)	SvPVX(prog)
+#define RX_WRAPLEN(prog)	SvCUR(prog)
+#define RX_CHECK_SUBSTR(prog)	(((struct regexp *)SvANY(prog))->check_substr)
+#define RX_REFCNT(prog)		SvREFCNT(prog)
+#if defined(__GNUC__) && !defined(PERL_GCC_BRACE_GROUPS_FORBIDDEN)
+#  define RX_EXTFLAGS(prog)						\
+    (*({								\
+	const REGEXP *const thwape = (prog);				\
+	assert(SvTYPE(thwape) == SVt_REGEXP);				\
+	&RXp_EXTFLAGS(SvANY(thwape));					\
+    }))
+#  define RX_ENGINE(prog)						\
+    (*({								\
+	const REGEXP *const thwape = (prog);				\
+	assert(SvTYPE(thwape) == SVt_REGEXP);				\
+	&SvANY(thwape)->engine;						\
+    }))
+#  define RX_SUBBEG(prog)						\
+    (*({								\
+	const REGEXP *const thwape = (prog);				\
+	assert(SvTYPE(thwape) == SVt_REGEXP);				\
+	&SvANY(thwape)->subbeg;						\
+    }))
+#  define RX_OFFS(prog)							\
+    (*({								\
+	const REGEXP *const thwape = (prog);				\
+	assert(SvTYPE(thwape) == SVt_REGEXP);				\
+	&SvANY(thwape)->offs;						\
+    }))
+#  define RX_NPARENS(prog)						\
+    (*({								\
+	const REGEXP *const thwape = (prog);				\
+	assert(SvTYPE(thwape) == SVt_REGEXP);				\
+	&SvANY(thwape)->nparens;					\
+    }))
+#else
+#  define RX_EXTFLAGS(prog)	RXp_EXTFLAGS((struct regexp *)SvANY(prog))
+#  define RX_ENGINE(prog)	(((struct regexp *)SvANY(prog))->engine)
+#  define RX_SUBBEG(prog)	(((struct regexp *)SvANY(prog))->subbeg)
+#  define RX_OFFS(prog)		(((struct regexp *)SvANY(prog))->offs)
+#  define RX_NPARENS(prog)	(((struct regexp *)SvANY(prog))->nparens)
+#endif
+#define RX_SUBLEN(prog)		(((struct regexp *)SvANY(prog))->sublen)
+#define RX_MINLEN(prog)		(((struct regexp *)SvANY(prog))->minlen)
+#define RX_MINLENRET(prog)	(((struct regexp *)SvANY(prog))->minlenret)
+#define RX_GOFS(prog)		(((struct regexp *)SvANY(prog))->gofs)
+#define RX_LASTPAREN(prog)	(((struct regexp *)SvANY(prog))->lastparen)
+#define RX_LASTCLOSEPAREN(prog)	(((struct regexp *)SvANY(prog))->lastcloseparen)
+#define RX_SEEN_EVALS(prog)	(((struct regexp *)SvANY(prog))->seen_evals)
+#define RX_SAVED_COPY(prog)	(((struct regexp *)SvANY(prog))->saved_copy)
+
 #endif /* PLUGGABLE_RE_EXTENSION */
 
 /* Stuff that needs to be included in the plugable extension goes below here */
 
 #ifdef PERL_OLD_COPY_ON_WRITE
 #define RX_MATCH_COPY_FREE(rx) \
-	STMT_START {if (rx->saved_copy) { \
-	    SV_CHECK_THINKFIRST_COW_DROP(rx->saved_copy); \
+	STMT_START {if (RX_SAVED_COPY(rx)) { \
+	    SV_CHECK_THINKFIRST_COW_DROP(RX_SAVED_COPY(rx)); \
 	} \
 	if (RX_MATCH_COPIED(rx)) { \
-	    Safefree(rx->subbeg); \
+	    Safefree(RX_SUBBEG(rx)); \
 	    RX_MATCH_COPIED_off(rx); \
 	}} STMT_END
 #else
 #define RX_MATCH_COPY_FREE(rx) \
 	STMT_START {if (RX_MATCH_COPIED(rx)) { \
-	    Safefree(rx->subbeg); \
+	    Safefree(RX_SUBBEG(rx)); \
 	    RX_MATCH_COPIED_off(rx); \
 	}} STMT_END
 #endif
 
-#define RX_MATCH_UTF8(prog)		((prog)->extflags & RXf_MATCH_UTF8)
-#define RX_MATCH_UTF8_on(prog)		((prog)->extflags |= RXf_MATCH_UTF8)
-#define RX_MATCH_UTF8_off(prog)		((prog)->extflags &= ~RXf_MATCH_UTF8)
+#define RXp_MATCH_UTF8(prog)		(RXp_EXTFLAGS(prog) & RXf_MATCH_UTF8)
+#define RX_MATCH_UTF8(prog)		(RX_EXTFLAGS(prog) & RXf_MATCH_UTF8)
+#define RX_MATCH_UTF8_on(prog)		(RX_EXTFLAGS(prog) |= RXf_MATCH_UTF8)
+#define RX_MATCH_UTF8_off(prog)		(RX_EXTFLAGS(prog) &= ~RXf_MATCH_UTF8)
 #define RX_MATCH_UTF8_set(prog, t)	((t) \
 			? (RX_MATCH_UTF8_on(prog), (PL_reg_match_utf8 = 1)) \
 			: (RX_MATCH_UTF8_off(prog), (PL_reg_match_utf8 = 0)))
@@ -375,8 +450,27 @@ and check for NULL.
 #define REXEC_IGNOREPOS	0x08		/* \G matches at start. */
 #define REXEC_NOT_FIRST	0x10		/* This is another iteration of //g. */
 
-#define ReREFCNT_inc(re) ((void)(re && re->refcnt++), re)
-#define ReREFCNT_dec(re) CALLREGFREE(re)
+#if defined(__GNUC__) && !defined(PERL_GCC_BRACE_GROUPS_FORBIDDEN)
+#  define ReREFCNT_inc(re)						\
+    ({									\
+	/* This is here to generate a casting warning if incorrect.  */	\
+	REGEXP *const zwapp = (re);					\
+	assert(SvTYPE(zwapp) == SVt_REGEXP);				\
+	SvREFCNT_inc(zwapp);						\
+	zwapp;								\
+    })
+#  define ReREFCNT_dec(re)						\
+    ({									\
+	/* This is here to generate a casting warning if incorrect.  */	\
+	REGEXP *const boff = (re);					\
+	SvREFCNT_dec(boff);						\
+    })
+#else
+#  define ReREFCNT_dec(re)	SvREFCNT_dec(re)
+#  define ReREFCNT_inc(re)	((REGEXP *) SvREFCNT_inc(re))
+#endif
+
+/* FIXME for plugins. */
 
 #define FBMcf_TAIL_DOLLAR	1
 #define FBMcf_TAIL_DOLLARM	2
@@ -397,7 +491,7 @@ typedef struct _reg_trie_accepted reg_trie_accepted;
  * Perl_regexec_flags and then passed to regtry(), regmatch() etc */
 
 typedef struct {
-    regexp *prog;
+    REGEXP *prog;
     char *bol;
     char *till;
     SV *sv;
@@ -467,7 +561,7 @@ typedef struct regmatch_state {
 	    struct regmatch_state *prev_yes_state;
 	    struct regmatch_state *prev_eval;
 	    struct regmatch_state *prev_curlyx;
-	    regexp	*prev_rex;
+	    REGEXP	*prev_rex;
 	    U32		toggle_reg_flags; /* what bits in PL_reg_flags to
 					    flip when transitioning between
 					    inner and outer rexen */
