@@ -30,7 +30,7 @@ END
 use ExtUtils::MakeMaker;
 
 # This will interfere with the PREREQ_PRINT tests.
-printf "Current package is: %s\n", __PACKAGE__ unless "@ARGV" =~ /PREREQ/;
+printf "Current package is: %s\n", __PACKAGE__ unless "@ARGV" =~ m/PREREQ/;
 
 WriteMakefile(
     NAME          => 'Big::Dummy',
@@ -105,7 +105,7 @@ sub setup_recurs {
 
         my $dir = dirname($file);
         mkpath $dir;
-        open(FILE, ">$file") || die "Can't create $file: $!";
+        open(FILE, ">", "$file") || die "Can't create $file: $!";
         print FILE $text;
         close FILE;
     }
