@@ -50,7 +50,7 @@ die "argv empty\n" unless @ARGV;
 die "too many in argv: @ARGV\n" unless @ARGV == 1;
 
 my $file = $ARGV[0];
-open OUT, ">$file" or die $!;
+open OUT, ">", "$file" or die $!;
 
 print OUT "Testing\n";
 close OUT
@@ -75,7 +75,7 @@ die "argv empty\n" unless @ARGV;
 die "too many in argv: @ARGV\n" unless @ARGV == 1;
 
 my $file = $ARGV[0];
-open OUT, ">$file" or die $!;
+open OUT, ">", "$file" or die $!;
 
 print OUT "Testing\n";
 close OUT
@@ -97,7 +97,7 @@ sub setup {
 
         my $dir = dirname($file);
         mkpath $dir;
-        open(FILE, ">$file") || die "Can't create $file: $!";
+        open(FILE, ">", "$file") || die "Can't create $file: $!";
         print FILE $text;
         close FILE;
     }
