@@ -34,7 +34,7 @@ sub setup_recurs {
 
         my $dir = dirname($file);
         mkpath $dir;
-        open(FILE, ">$file") || die "Can't create $file: $!";
+        open(FILE, ">", "$file") || die "Can't create $file: $!";
         print FILE $text;
         close FILE;
     }
