@@ -27,7 +27,7 @@ $MYPKG = eval { (caller)[0] };
 
 sub stripname( $ ) {
    local $_ = shift;
-   return /(\w[.\w]*)\s*$/ ? $1 : $_;
+   return m/(\w[.\w]*)\s*$/ ? $1 : $_;
 }
 
 sub msgcmp( $ $ ) {
@@ -36,8 +36,8 @@ sub msgcmp( $ $ ) {
    for ($line1, $line2) {
       ## remove filenames from error messages to avoid any
       ## filepath naming differences between OS platforms
-      s/(at line \S+ in file) .*\W(\w+\.[tT])\s*$/$1 \L$2\E/;
-      s/.*\W(\w+\.[tT]) (has \d+ pod syntax error)/\L$1\E $2/;
+      s/(at line \S+ in file) .*\W(\w+\.[tT])\s*$/{"$1 ".lc($2)}/;
+      s/.*\W(\w+\.[tT]) (has \d+ pod syntax error)/{lc($1)." $2"}/;
    }
    return ($line1 ne $line2);
 }
