@@ -72,6 +72,8 @@ char *
 Perl_uvuni_to_utf8_flags(pTHX_ char *ds, UV uv, UV flags)
 {
     U8 *d = (U8*)ds;
+    PERL_ARGS_ASSERT_UVUNI_TO_UTF8_FLAGS;
+
     if (ckWARN(WARN_UTF8)) {
 	 if (UNICODE_IS_SURROGATE(uv) &&
 	     !(flags & UNICODE_ALLOW_SURROGATE))
@@ -200,6 +202,8 @@ S_is_utf8_char_slow(const char *s, const STRLEN len)
     STRLEN slen;
     UV uv, ouv;
 
+    PERL_ARGS_ASSERT_IS_UTF8_CHAR_SLOW;
+
     if (UTF8_IS_INVARIANT(u))
 	return 1;
 
@@ -246,6 +250,8 @@ STRLEN
 Perl_is_utf8_char(pTHX_ const char *s)
 {
     const STRLEN len = UTF8SKIP(s);
+
+    PERL_ARGS_ASSERT_IS_UTF8_CHAR;
     PERL_UNUSED_CONTEXT;
 #ifdef IS_UTF8_CHAR
     if (IS_UTF8_CHAR_FAST(len))
@@ -273,6 +279,7 @@ Perl_is_utf8_string(pTHX_ const char *s, STRLEN len)
     const char* const send = s + (len ? len : strlen((const char *)s));
     const char* x = s;
 
+    PERL_ARGS_ASSERT_IS_UTF8_STRING;
     PERL_UNUSED_CONTEXT;
 
     while (x < send) {
@@ -338,6 +345,8 @@ Perl_is_utf8_string_loclen(pTHX_ const char *s, STRLEN len, const char **ep, STR
     const char* x = s;
     STRLEN c;
     STRLEN outlen = 0;
+
+    PERL_ARGS_ASSERT_IS_UTF8_STRING_LOCLEN;
     PERL_UNUSED_CONTEXT;
 
     while (x < send) {
@@ -411,6 +420,8 @@ Perl_utf8n_to_uvuni(pTHX_ const char *s, STRLEN curlen, STRLEN *retlen, U32 flag
     STRLEN expectlen = 0;
     U32 warning = 0;
 
+    PERL_ARGS_ASSERT_UTF8N_TO_UVUNI;
+
 /* This list is a superset of the UTF8_ALLOW_XXX. */
 
 #define UTF8_WARN_EMPTY				 1
@@ -537,7 +548,7 @@ malformed:
     }
 
     if (dowarn) {
-	SV* const sv = sv_2mortal(newSVpvs("Malformed UTF-8 character "));
+	SV* const sv = newSVpvs_flags("Malformed UTF-8 character ", SVs_TEMP);
 
 	switch (warning) {
 	case 0: /* Intentionally empty. */ break;
@@ -618,6 +629,8 @@ returned and retlen is set, if possible, to -1.
 UV
 Perl_utf8_to_uvchr(pTHX_ const char *s, STRLEN *retlen)
 {
+    PERL_ARGS_ASSERT_UTF8_TO_UVCHR;
+
     return utf8n_to_uvchr(s, UTF8_MAXBYTES, retlen,
 			  ckWARN(WARN_UTF8) ? 0 : UTF8_ALLOW_ANY);
 }
@@ -641,6 +654,8 @@ returned and retlen is set, if possible, to -1.
 UV
 Perl_utf8_to_uvuni(pTHX_ const char *s, STRLEN *retlen)
 {
+    PERL_ARGS_ASSERT_UTF8_TO_UVUNI;
+
     /* Call the low level routine asking for checks */
     return Perl_utf8n_to_uvuni(aTHX_ s, UTF8_MAXBYTES, retlen,
 			       ckWARN(WARN_UTF8) ? 0 : UTF8_ALLOW_ANY);
@@ -663,6 +678,8 @@ Perl_utf8_length(pTHX_ const char *s, const char *e)
     STRLEN len = 0;
     char t = 0;
 
+    PERL_ARGS_ASSERT_UTF8_LENGTH;
+
     /* Note: cannot use UTF8_IS_...() too eagerly here since e.g.
      * the bitops (especially ~) can create illegal UTF-8.
      * In other words: in Perl UTF-8 is not just for Unicode. */
@@ -704,6 +721,8 @@ same UTF-8 buffer.
 IV
 Perl_utf8_distance(pTHX_ const char *a, const char *b)
 {
+    PERL_ARGS_ASSERT_UTF8_DISTANCE;
+
     return (a < b) ? -1 * (IV) utf8_length(a, b) : (IV) utf8_length(b, a);
 }
 
@@ -723,6 +742,8 @@ on the first byte of character or just after the last byte of a character.
 char *
 Perl_utf8_hop(pTHX_ const char *s, I32 off)
 {
+    PERL_ARGS_ASSERT_UTF8_HOP;
+
     PERL_UNUSED_CONTEXT;
     /* Note: cannot use UTF8_IS_...() too eagerly here since e.g
      * the bitops (especially ~) can create illegal UTF-8.
@@ -762,6 +783,8 @@ Perl_utf8_to_bytes(pTHX_ char *s, STRLEN *len)
     char * const send = s + *len;
     char *d;
 
+    PERL_ARGS_ASSERT_UTF8_TO_BYTES;
+
     /* ensure valid UTF-8 and chars < 256 before updating string */
     while (s < send) {
         char c = *s++;
@@ -806,6 +829,8 @@ Perl_bytes_from_utf8(pTHX_ const char *s, STRLEN *len, bool *is_utf8)
     const char *send;
     I32 count = 0;
 
+    PERL_ARGS_ASSERT_BYTES_FROM_UTF8;
+
     PERL_UNUSED_CONTEXT;
     if (!*is_utf8)
         return (char *)start;
@@ -859,6 +884,8 @@ Perl_bytes_to_utf8(pTHX_ const char *s, STRLEN *len)
     const char * const send = s + (*len);
     char *d;
     char *dst;
+
+    PERL_ARGS_ASSERT_BYTES_TO_UTF8;
     PERL_UNUSED_CONTEXT;
 
     Newx(d, (*len) * 2 + 1, char);
@@ -890,6 +917,8 @@ Perl_utf16_to_utf8(pTHX_ const char* p, char* d, I32 bytelen, I32 *newlen)
     const char* pend;
     char* dstart = d;
 
+    PERL_ARGS_ASSERT_UTF16_TO_UTF8;
+
     if (bytelen == 1 && p[0] == 0) { /* Be understanding. */
 	 d[0] = 0;
 	 *newlen = 1;
@@ -949,6 +978,9 @@ Perl_utf16_to_utf8_reversed(pTHX_ char* p, char* d, I32 bytelen, I32 *newlen)
 {
     char* s = p;
     char* const send = s + bytelen;
+
+    PERL_ARGS_ASSERT_UTF16_TO_UTF8_REVERSED;
+
     while (s < send) {
 	const char tmp = s[0];
 	s[0] = s[1];
@@ -1075,6 +1107,8 @@ Perl_is_uni_xdigit(pTHX_ UV c)
 UV
 Perl_to_uni_upper(pTHX_ UV c, char* p, STRLEN *lenp)
 {
+    PERL_ARGS_ASSERT_TO_UNI_UPPER;
+
     uvchr_to_utf8(p, c);
     return to_utf8_upper(p, p, lenp);
 }
@@ -1082,6 +1116,8 @@ Perl_to_uni_upper(pTHX_ UV c, char* p, STRLEN *lenp)
 UV
 Perl_to_uni_title(pTHX_ UV c, char* p, STRLEN *lenp)
 {
+    PERL_ARGS_ASSERT_TO_UNI_TITLE;
+
     uvchr_to_utf8(p, c);
     return to_utf8_title(p, p, lenp);
 }
@@ -1089,6 +1125,8 @@ Perl_to_uni_title(pTHX_ UV c, char* p, STRLEN *lenp)
 UV
 Perl_to_uni_lower(pTHX_ UV c, char* p, STRLEN *lenp)
 {
+    PERL_ARGS_ASSERT_TO_UNI_LOWER;
+
     uvchr_to_utf8(p, c);
     return to_utf8_lower(p, p, lenp);
 }
@@ -1096,6 +1134,8 @@ Perl_to_uni_lower(pTHX_ UV c, char* p, STRLEN *lenp)
 UV
 Perl_to_uni_fold(pTHX_ UV c, char* p, STRLEN *lenp)
 {
+    PERL_ARGS_ASSERT_TO_UNI_FOLD;
+
     uvchr_to_utf8(p, c);
     return to_utf8_fold(p, p, lenp);
 }
@@ -1221,6 +1261,9 @@ S_is_utf8_common(pTHX_ const char *const p, SV **swash,
 		 const char *const swashname)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_COMMON;
+
     if (!is_utf8_char(p))
 	return FALSE;
     if (!*swash)
@@ -1232,6 +1275,9 @@ bool
 Perl_is_utf8_alnum(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_ALNUM;
+
     /* NOTE: "IsWord", not "IsAlnum", since Alnum is a true
      * descendant of isalnum(3), in other words, it doesn't
      * contain the '_'. --jhi */
@@ -1242,6 +1288,9 @@ bool
 Perl_is_utf8_alnumc(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_ALNUMC;
+
     return is_utf8_common(p, &PL_utf8_alnumc, "IsAlnumC");
 }
 
@@ -1249,6 +1298,9 @@ bool
 Perl_is_utf8_idfirst(pTHX_ const char *p) /* The naming is historical. */
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_IDFIRST;
+
     if (*p == '_')
 	return TRUE;
     /* is_utf8_idstart would be more logical. */
@@ -1259,6 +1311,9 @@ bool
 Perl_is_utf8_idcont(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_IDCONT;
+
     if (*p == '_')
 	return TRUE;
     return is_utf8_common(p, &PL_utf8_idcont, "IdContinue");
@@ -1268,6 +1323,9 @@ bool
 Perl_is_utf8_alpha(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_ALPHA;
+
     return is_utf8_common(p, &PL_utf8_alpha, "IsAlpha");
 }
 
@@ -1275,6 +1333,9 @@ bool
 Perl_is_utf8_ascii(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_ASCII;
+
     return is_utf8_common(p, &PL_utf8_ascii, "IsAscii");
 }
 
@@ -1282,6 +1343,9 @@ bool
 Perl_is_utf8_space(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_SPACE;
+
     return is_utf8_common(p, &PL_utf8_space, "IsSpacePerl");
 }
 
@@ -1289,6 +1353,9 @@ bool
 Perl_is_utf8_digit(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_DIGIT;
+
     return is_utf8_common(p, &PL_utf8_digit, "IsDigit");
 }
 
@@ -1296,6 +1363,9 @@ bool
 Perl_is_utf8_upper(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_UPPER;
+
     return is_utf8_common(p, &PL_utf8_upper, "IsUppercase");
 }
 
@@ -1303,6 +1373,9 @@ bool
 Perl_is_utf8_lower(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_LOWER;
+
     return is_utf8_common(p, &PL_utf8_lower, "IsLowercase");
 }
 
@@ -1310,6 +1383,9 @@ bool
 Perl_is_utf8_cntrl(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_CNTRL;
+
     return is_utf8_common(p, &PL_utf8_cntrl, "IsCntrl");
 }
 
@@ -1317,6 +1393,9 @@ bool
 Perl_is_utf8_graph(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_GRAPH;
+
     return is_utf8_common(p, &PL_utf8_graph, "IsGraph");
 }
 
@@ -1324,6 +1403,9 @@ bool
 Perl_is_utf8_print(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_PRINT;
+
     return is_utf8_common(p, &PL_utf8_print, "IsPrint");
 }
 
@@ -1331,6 +1413,9 @@ bool
 Perl_is_utf8_punct(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_PUNCT;
+
     return is_utf8_common(p, &PL_utf8_punct, "IsPunct");
 }
 
@@ -1338,6 +1423,9 @@ bool
 Perl_is_utf8_xdigit(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_XDIGIT;
+
     return is_utf8_common(p, &PL_utf8_xdigit, "Isxdigit");
 }
 
@@ -1345,6 +1433,9 @@ bool
 Perl_is_utf8_mark(pTHX_ const char *p)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_IS_UTF8_MARK;
+
     return is_utf8_common(p, &PL_utf8_mark, "IsM");
 }
 
@@ -1380,12 +1471,14 @@ Perl_to_utf8_case(pTHX_ const char *p, char* ustrp, STRLEN *lenp,
     dVAR;
     char tmpbuf[UTF8_MAXBYTES_CASE+1];
     STRLEN len = 0;
-
     const UV uv0 = utf8_to_uvchr(p, NULL);
     /* The NATIVE_TO_UNI() and UNI_TO_NATIVE() mappings
      * are necessary in EBCDIC, they are redundant no-ops
      * in ASCII-ish platforms, and hopefully optimized away. */
     const UV uv1 = NATIVE_TO_UNI(uv0);
+
+    PERL_ARGS_ASSERT_TO_UTF8_CASE;
+
     uvuni_to_utf8(tmpbuf, uv1);
 
     if (!*swashp) /* load on-demand */
@@ -1470,6 +1563,9 @@ UV
 Perl_to_utf8_upper(pTHX_ const char *p, char* ustrp, STRLEN *lenp)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_TO_UTF8_UPPER;
+
     return Perl_to_utf8_case(aTHX_ p, ustrp, lenp,
                              &PL_utf8_toupper, "ToUpper", "utf8::ToSpecUpper");
 }
@@ -1491,6 +1587,9 @@ UV
 Perl_to_utf8_title(pTHX_ const char *p, char* ustrp, STRLEN *lenp)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_TO_UTF8_TITLE;
+
     return Perl_to_utf8_case(aTHX_ p, ustrp, lenp,
                              &PL_utf8_totitle, "ToTitle", "utf8::ToSpecTitle");
 }
@@ -1512,6 +1611,9 @@ UV
 Perl_to_utf8_lower(pTHX_ const char *p, char* ustrp, STRLEN *lenp)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_TO_UTF8_LOWER;
+
     return Perl_to_utf8_case(aTHX_ p, ustrp, lenp,
                              &PL_utf8_tolower, "ToLower", "utf8::ToSpecLower");
 }
@@ -1534,6 +1636,9 @@ UV
 Perl_to_utf8_fold(pTHX_ const char *p, char* ustrp, STRLEN *lenp)
 {
     dVAR;
+
+    PERL_ARGS_ASSERT_TO_UTF8_FOLD;
+
     return Perl_to_utf8_case(aTHX_ p, ustrp, lenp,
                              &PL_utf8_tofold, "ToFold", "utf8::ToSpecFold");
 }
@@ -1555,6 +1660,8 @@ Perl_swash_init(pTHX_ const char* pkg, const char* name, SV *listsv, I32 minbits
     HV * const stash = gv_stashpvn(pkg, pkg_len, 0);
     SV* errsv_save;
 
+    PERL_ARGS_ASSERT_SWASH_INIT;
+
     PUSHSTACKi(PERLSI_MAGIC);
     ENTER;
     SAVEI32(PL_hints);
@@ -1580,11 +1687,11 @@ Perl_swash_init(pTHX_ const char* pkg, const char* name, SV *listsv, I32 minbits
     SPAGAIN;
     PUSHMARK(SP);
     EXTEND(SP,5);
-    PUSHs(sv_2mortal(newSVpvn(pkg, pkg_len)));
-    PUSHs(sv_2mortal(newSVpvn(name, name_len)));
+    mPUSHp(pkg, pkg_len);
+    mPUSHp(name, name_len);
     PUSHs(listsv);
-    PUSHs(sv_2mortal(newSViv(minbits)));
-    PUSHs(sv_2mortal(newSViv(none)));
+    mPUSHi(minbits);
+    mPUSHi(none);
     PUTBACK;
     errsv_save = newSVsv(ERRSV);
     if (call_method("SWASHNEW", G_SCALAR))
@@ -1637,6 +1744,8 @@ Perl_swash_fetch(pTHX_ SV *swash, const char *ptr, bool do_utf8)
     char tmputf8[2];
     const UV c = NATIVE_TO_ASCII(*ptr);
 
+    PERL_ARGS_ASSERT_SWASH_FETCH;
+
     if (!do_utf8 && !UNI_IS_INVARIANT(c)) {
 	tmputf8[0] = UTF8_EIGHT_BIT_HI(c);
 	tmputf8[1] = UTF8_EIGHT_BIT_LO(c);
@@ -1731,7 +1840,6 @@ S_swash_get(pTHX_ SV* swash, UV start, UV span)
     SV *swatch;
     char *l, *lend, *x, *xend, *s;
     STRLEN lcur, xcur, scur;
-
     HV* const hv = (HV*)SvRV(swash);
     SV** const listsvp = hv_fetchs(hv, "LIST", FALSE);
     SV** const typesvp = hv_fetchs(hv, "TYPE", FALSE);
@@ -1745,6 +1853,8 @@ S_swash_get(pTHX_ SV* swash, UV start, UV span)
     const UV     none  = SvUV(*nonesvp);
     const UV     end   = start + span;
 
+    PERL_ARGS_ASSERT_SWASH_GET;
+
     if (bits != 1 && bits != 8 && bits != 16 && bits != 32) {
 	Perl_croak(aTHX_ "panic: swash_get doesn't expect bits %"UVuf,
 						 (UV)bits);
@@ -2056,12 +2166,16 @@ is the recommended wide native character-aware way of saying
 char *
 Perl_uvchr_to_utf8(pTHX_ char *d, UV uv)
 {
+    PERL_ARGS_ASSERT_UVCHR_TO_UTF8;
+
     return Perl_uvuni_to_utf8_flags(aTHX_ d, NATIVE_TO_UNI(uv), 0);
 }
 
 char *
 Perl_uvchr_to_utf8_flags(pTHX_ char *d, UV uv, UV flags)
 {
+    PERL_ARGS_ASSERT_UVCHR_TO_UTF8_FLAGS;
+
     return Perl_uvuni_to_utf8_flags(aTHX_ d, NATIVE_TO_UNI(uv), flags);
 }
 
@@ -2086,6 +2200,9 @@ Perl_utf8n_to_uvchr(pTHX_ const char *s, STRLEN curlen, STRLEN *retlen,
 U32 flags)
 {
     const UV uv = Perl_utf8n_to_uvuni(aTHX_ s, curlen, retlen, flags);
+
+    PERL_ARGS_ASSERT_UTF8N_TO_UVCHR;
+
     return UNI_TO_NATIVE(uv);
 }
 
@@ -2112,6 +2229,8 @@ Perl_pv_uni_display(pTHX_ SV *dsv, const char *spv, STRLEN len, STRLEN pvlim, UV
     int truncated = 0;
     const char *s, *e;
 
+    PERL_ARGS_ASSERT_PV_UNI_DISPLAY;
+
     sv_setpvn(dsv, "", 0);
     for (s = (const char *)spv, e = s + len; s < e; s += UTF8SKIP(s)) {
 	 UV u;
@@ -2181,7 +2300,8 @@ The pointer to the PV of the dsv is returned.
 char *
 Perl_sv_uni_display(pTHX_ SV *dsv, SV *ssv, STRLEN pvlim, UV flags)
 {
-     return Perl_pv_uni_display(aTHX_ dsv, SvPVX_const(ssv),
+    PERL_ARGS_ASSERT_SV_UNI_DISPLAY;
+    return Perl_pv_uni_display(aTHX_ dsv, SvPVX_const(ssv),
 				SvCUR(ssv), pvlim, flags);
 }
 
@@ -2224,6 +2344,8 @@ Perl_ibcmp_utf8(pTHX_ const char *s1, char **pe1, register UV l1, const char *s2
      char foldbuf2[UTF8_MAXBYTES_CASE+1];
      STRLEN foldlen1, foldlen2;
      bool match;
+
+     PERL_ARGS_ASSERT_IBCMP_UTF8;
      
      if (pe1)
 	  e1 = *pe1;
@@ -2234,6 +2356,9 @@ Perl_ibcmp_utf8(pTHX_ const char *s1, char **pe1, register UV l1, const char *s2
      if (e2 == 0 || (l2 && l2 < (UV)(e2 - s2)))
 	  f2 = s2 + l2;
 
+     /* This shouldn't happen. However, putting an assert() there makes some
+      * tests fail. */
+     /* assert((e1 == 0 && f1 == 0) || (e2 == 0 && f2 == 0) || (f1 == 0 && f2 == 0)); */
      if ((e1 == 0 && f1 == 0) || (e2 == 0 && f2 == 0) || (f1 == 0 && f2 == 0))
 	  return 1; /* mismatch; possible infinite loop or false positive */
 
