@@ -62,6 +62,7 @@ my $tree = {
        	'pack'		=> [ 5.008, DEFAULT_OFF],
        	'unpack'	=> [ 5.008, DEFAULT_OFF],
        	'threads'	=> [ 5.008, DEFAULT_OFF],
+       	'imprecision'	=> [ 5.011, DEFAULT_OFF],
 
        	 #'default'	=> [ 5.008, DEFAULT_ON ],
   	}],
@@ -268,6 +269,9 @@ print WARN <<'EOM' ;
 
 /* if PL_warnhook is set to this value, then warnings die */
 #define PERL_WARNHOOK_FATAL	(&PL_sv_placeholder)
+/* if PL_diehook is set to this value, then a fatal warning is printed */
+#define PERL_DIEHOOK_FATAL	(&PL_sv_placeholder)
+#define PERL_DIEHOOK_IGNORE	(&PL_sv_undef)
 EOM
 
 my $offset = 0 ;
@@ -556,14 +560,6 @@ KEYWORDS
 
 our $All = "" ; vec($All, $Offsets{'all'}, 2) = 3 ;
 
-sub Croaker
-{
-    require Carp::Heavy; # this initializes %CarpInternal
-    local $Carp::CarpInternal{'warnings'};
-    delete $Carp::CarpInternal{'warnings'};
-    Carp::croak(@_);
-}
-
 sub bits
 {
     # called from B::Deparse.pm
@@ -590,7 +586,7 @@ sub bits
 	    $mask ^&^= ^~^($DeadBits{$word}^|^$All) if $no_fatal ;
 	}
 	else
-          { Croaker("Unknown warnings category '$word'")}
+          { die("Unknown warnings category '$word'")}
     }
 
     return $mask ;
@@ -628,7 +624,7 @@ sub import
 	    $mask ^&^= ^~^($DeadBits{$word}^|^$All) if $no_fatal ;
 	}
 	else
-          { Croaker("Unknown warnings category '$word'")}
+          { die("Unknown warnings category '$word'")}
     }
 
     ${^WARNING_BITS} = $mask ;
@@ -656,7 +652,7 @@ sub unimport
 	    $mask ^&^= ^~^($catmask ^|^ $DeadBits{$word} ^|^ $All);
 	}
 	else
-          { Croaker("Unknown warnings category '$word'")}
+          { die("Unknown warnings category '$word'")}
     }
 
     ${^WARNING_BITS} = $mask ;
@@ -674,19 +670,19 @@ sub __chk
         # check the category supplied.
         $category = shift ;
         if (my $type = ref $category) {
-            Croaker("not an object")
+            die("not an object")
                 if exists $builtin_type{$type};
 	    $category = $type;
             $isobj = 1 ;
         }
         $offset = $Offsets{$category};
-        Croaker("Unknown warnings category '$category'")
+        die("Unknown warnings category '$category'")
 	    unless defined $offset;
     }
     else {
         $category = (caller(1))[0] ;
         $offset = $Offsets{$category};
-        Croaker("package '$category' not registered for warnings")
+        die("package '$category' not registered for warnings")
 	    unless defined $offset ;
     }
 
@@ -701,21 +697,16 @@ sub __chk
 	$i -= 2 ;
     }
     else {
-        $i = _error_loc(); # see where Carp will allocate the error
+        $i = 2;
     }
 
     my $callers_bitmask = (caller($i))[9] ;
     return ($callers_bitmask, $offset, $i) ;
 }
 
-sub _error_loc {
-    require Carp::Heavy;
-    goto &Carp::short_error_loc; # don't introduce another stack frame
-}                                                             
-
 sub enabled
 {
-    Croaker("Usage: warnings::enabled([category])")
+    die("Usage: warnings::enabled([category])")
 	unless @_ == 1 || @_ == 0 ;
 
     my ($callers_bitmask, $offset, $i) = __chk(@_) ;
@@ -728,21 +719,20 @@ sub enabled
 
 sub warn
 {
-    Croaker("Usage: warnings::warn([category,] 'message')")
+    die("Usage: warnings::warn([category,] 'message')")
 	unless @_ == 2 || @_ == 1 ;
 
     my $message = pop ;
     my ($callers_bitmask, $offset, $i) = __chk(@_) ;
-    require Carp;
-    Carp::croak($message)
+    die($message)
 	if vec($callers_bitmask, $offset+1, 1) ||
 	   vec($callers_bitmask, $Offsets{'all'}+1, 1) ;
-    Carp::carp($message) ;
+    CORE::warn($message) ;
 }
 
 sub warnif
 {
-    Croaker("Usage: warnings::warnif([category,] 'message')")
+    die("Usage: warnings::warnif([category,] 'message')")
 	unless @_ == 2 || @_ == 1 ;
 
     my $message = pop ;
@@ -753,12 +743,11 @@ sub warnif
             	(vec($callers_bitmask, $offset, 1) ||
             	vec($callers_bitmask, $Offsets{'all'}, 1)) ;
 
-    require Carp;
-    Carp::croak($message)
+    die($message)
 	if vec($callers_bitmask, $offset+1, 1) ||
 	   vec($callers_bitmask, $Offsets{'all'}+1, 1) ;
 
-    Carp::carp($message) ;
+    CORE::warn($message) ;
 }
 
 1;
